/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __PERF_EVENT_STACKMAP_SKEL_H__
#define __PERF_EVENT_STACKMAP_SKEL_H__

#include <stdlib.h>
#include <bpf/libbpf.h>

struct perf_event_stackmap {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *stackmap;
		struct bpf_map *stackdata_map;
		struct bpf_map *data;
	} maps;
	struct {
		struct bpf_program *oncpu;
	} progs;
	struct {
		struct bpf_link *oncpu;
	} links;
	struct perf_event_stackmap__data {
		long int stackid_kernel;
		long int stackid_user;
		long int stack_kernel;
		long int stack_user;
	} *data;
};

static void
perf_event_stackmap__destroy(struct perf_event_stackmap *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
perf_event_stackmap__create_skeleton(struct perf_event_stackmap *obj);

static inline struct perf_event_stackmap *
perf_event_stackmap__open_opts(const struct bpf_object_open_opts *opts)
{
	struct perf_event_stackmap *obj;

	obj = (struct perf_event_stackmap *)calloc(1, sizeof(*obj));
	if (!obj)
		return NULL;
	if (perf_event_stackmap__create_skeleton(obj))
		goto err;
	if (bpf_object__open_skeleton(obj->skeleton, opts))
		goto err;

	return obj;
err:
	perf_event_stackmap__destroy(obj);
	return NULL;
}

static inline struct perf_event_stackmap *
perf_event_stackmap__open(void)
{
	return perf_event_stackmap__open_opts(NULL);
}

static inline int
perf_event_stackmap__load(struct perf_event_stackmap *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct perf_event_stackmap *
perf_event_stackmap__open_and_load(void)
{
	struct perf_event_stackmap *obj;

	obj = perf_event_stackmap__open();
	if (!obj)
		return NULL;
	if (perf_event_stackmap__load(obj)) {
		perf_event_stackmap__destroy(obj);
		return NULL;
	}
	return obj;
}

static inline int
perf_event_stackmap__attach(struct perf_event_stackmap *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
perf_event_stackmap__detach(struct perf_event_stackmap *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline int
perf_event_stackmap__create_skeleton(struct perf_event_stackmap *obj)
{
	struct bpf_object_skeleton *s;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)
		return -1;
	obj->skeleton = s;

	s->sz = sizeof(*s);
	s->name = "perf_event_stackmap";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 3;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps)
		goto err;

	s->maps[0].name = "stackmap";
	s->maps[0].map = &obj->maps.stackmap;

	s->maps[1].name = "stackdata_map";
	s->maps[1].map = &obj->maps.stackdata_map;

	s->maps[2].name = "perf_eve.data";
	s->maps[2].map = &obj->maps.data;
	s->maps[2].mmaped = (void **)&obj->data;

	/* programs */
	s->prog_cnt = 1;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs)
		goto err;

	s->progs[0].name = "oncpu";
	s->progs[0].prog = &obj->progs.oncpu;
	s->progs[0].link = &obj->links.oncpu;

	s->data_sz = 8424;
	s->data = (void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x28\x1b\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x17\0\
\x01\0\xbf\x16\0\0\0\0\0\0\xb7\x01\0\0\0\0\0\0\x63\x1a\xfc\xff\0\0\0\0\xbf\x61\
\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x03\0\0\0\0\0\0\x85\0\0\0\
\x1b\0\0\0\xc5\0\x04\0\x01\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x02\0\
\0\x02\0\0\0\x7b\x21\0\0\0\0\0\0\xbf\x61\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\xb7\x03\0\0\0\x01\0\0\x85\0\0\0\x1b\0\0\0\xc5\0\x04\0\x01\0\0\0\x18\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x02\0\0\x02\0\0\0\x7b\x21\0\0\0\0\0\0\xbf\
\xa2\0\0\0\0\0\0\x07\x02\0\0\xfc\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x85\0\0\0\x01\0\0\0\xbf\x07\0\0\0\0\0\0\x15\x07\x14\0\0\0\0\0\xbf\x61\0\0\0\
\0\0\0\xbf\x72\0\0\0\0\0\0\xb7\x03\0\0\xf8\x03\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\
\0\x43\0\0\0\xc5\0\x04\0\x01\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x02\
\0\0\x02\0\0\0\x7b\x21\0\0\0\0\0\0\xbf\x61\0\0\0\0\0\0\xbf\x72\0\0\0\0\0\0\xb7\
\x03\0\0\xf8\x03\0\0\xb7\x04\0\0\0\x01\0\0\x85\0\0\0\x43\0\0\0\xc5\0\x04\0\x01\
\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x02\0\0\x02\0\0\0\x7b\x21\0\0\0\
\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\
\x01\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x01\0\x51\x10\0\0\0\0\
\0\0\0\xa0\x01\0\0\0\0\0\0\x01\0\x56\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x10\0\0\0\
\0\0\0\0\xb8\0\0\0\0\0\0\0\x02\0\x30\x9f\xb8\0\0\0\0\0\0\0\xa0\x01\0\0\0\0\0\0\
\x02\0\x7a\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\xe0\0\0\0\0\0\
\0\0\x01\0\x50\x18\x01\0\0\0\0\0\0\x90\x01\0\0\0\0\0\0\x01\0\x50\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\xe8\0\0\0\0\0\0\0\xa0\x01\0\0\0\0\0\0\x01\0\x57\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x01\x11\x01\x25\x0e\x13\x05\x03\x0e\x10\x17\x1b\x0e\x11\
\x01\x12\x06\0\0\x02\x34\0\x03\x0e\x49\x13\x3f\x19\x3a\x0b\x3b\x0b\x02\x18\0\0\
\x03\x24\0\x03\x0e\x3e\x0b\x0b\x0b\0\0\x04\x01\x01\x49\x13\0\0\x05\x21\0\x49\
\x13\x37\x0b\0\0\x06\x24\0\x03\x0e\x0b\x0b\x3e\x0b\0\0\x07\x13\x01\x0b\x0b\x3a\
\x0b\x3b\x0b\0\0\x08\x0d\0\x03\x0e\x49\x13\x3a\x0b\x3b\x0b\x38\x0b\0\0\x09\x0f\
\0\x49\x13\0\0\x0a\x21\0\x49\x13\x37\x05\0\0\x0b\x16\0\x49\x13\x03\x0e\x3a\x0b\
\x3b\x0b\0\0\x0c\x34\0\x03\x0e\x49\x13\x3a\x0b\x3b\x05\0\0\x0d\x15\x01\x49\x13\
\x27\x19\0\0\x0e\x05\0\x49\x13\0\0\x0f\x0f\0\0\0\x10\x34\0\x03\x0e\x49\x13\x3a\
\x0b\x3b\x0b\0\0\x11\x26\0\0\0\x12\x04\x01\x49\x13\x0b\x0b\x3a\x0b\x3b\x05\0\0\
\x13\x28\0\x03\x0e\x1c\x0f\0\0\x14\x2e\x01\x11\x01\x12\x06\x40\x18\x97\x42\x19\
\x03\x0e\x3a\x0b\x3b\x0b\x27\x19\x49\x13\x3f\x19\0\0\x15\x05\0\x02\x17\x03\x0e\
\x3a\x0b\x3b\x0b\x49\x13\0\0\x16\x34\0\x02\x17\x03\x0e\x3a\x0b\x3b\x0b\x49\x13\
\0\0\0\xf4\x02\0\0\x04\0\0\0\0\0\x08\x01\0\0\0\0\x0c\0\x44\0\0\0\0\0\0\0\x60\0\
\0\0\0\0\0\0\0\0\0\0\xa0\x01\0\0\x02\xd0\0\0\0\x3f\0\0\0\x01\x19\x09\x03\0\0\0\
\0\0\0\0\0\x03\xdf\0\0\0\x05\x08\x02\xe8\0\0\0\x3f\0\0\0\x01\x1a\x09\x03\0\0\0\
\0\0\0\0\0\x02\xf5\0\0\0\x3f\0\0\0\x01\x1b\x09\x03\0\0\0\0\0\0\0\0\x02\x02\x01\
\0\0\x3f\0\0\0\x01\x1c\x09\x03\0\0\0\0\0\0\0\0\x02\x0d\x01\0\0\x9a\0\0\0\x01\
\x3b\x09\x03\0\0\0\0\0\0\0\0\x04\xa6\0\0\0\x05\xad\0\0\0\x04\0\x03\x15\x01\0\0\
\x06\x01\x06\x1a\x01\0\0\x08\x07\x02\x2e\x01\0\0\xc9\0\0\0\x01\x10\x09\x03\0\0\
\0\0\0\0\0\0\x07\x20\x01\x0b\x08\x37\x01\0\0\xfe\0\0\0\x01\x0c\0\x08\x40\x01\0\
\0\x16\x01\0\0\x01\x0d\x08\x08\x4c\x01\0\0\x28\x01\0\0\x01\x0e\x10\x08\x55\x01\
\0\0\x39\x01\0\0\x01\x0f\x18\0\x09\x03\x01\0\0\x04\x0f\x01\0\0\x05\xad\0\0\0\
\x07\0\x03\x3c\x01\0\0\x05\x04\x09\x1b\x01\0\0\x04\x0f\x01\0\0\x0a\xad\0\0\0\0\
\x40\0\x09\x2d\x01\0\0\x04\x0f\x01\0\0\x05\xad\0\0\0\x04\0\x09\x3e\x01\0\0\x04\
\x0f\x01\0\0\x0a\xad\0\0\0\xf8\x03\0\x02\x60\x01\0\0\x60\x01\0\0\x01\x17\x09\
\x03\0\0\0\0\0\0\0\0\x07\x20\x01\x12\x08\x37\x01\0\0\x95\x01\0\0\x01\x13\0\x08\
\x40\x01\0\0\xa6\x01\0\0\x01\x14\x08\x08\x6e\x01\0\0\xb7\x01\0\0\x01\x15\x10\
\x08\x85\x01\0\0\xce\x01\0\0\x01\x16\x18\0\x09\x9a\x01\0\0\x04\x0f\x01\0\0\x05\
\xad\0\0\0\x06\0\x09\xab\x01\0\0\x04\x0f\x01\0\0\x05\xad\0\0\0\x01\0\x09\xbc\
\x01\0\0\x0b\xc7\x01\0\0\x7f\x01\0\0\x02\x12\x03\x72\x01\0\0\x07\x04\x09\xd3\
\x01\0\0\x0b\xde\x01\0\0\xa8\x01\0\0\x01\x0a\x04\xea\x01\0\0\x05\xad\0\0\0\x7f\
\0\x0b\xf5\x01\0\0\xa2\x01\0\0\x02\x16\x03\x8b\x01\0\0\x07\x08\x0c\xb6\x01\0\0\
\x08\x02\0\0\x03\xef\x02\x09\x0d\x02\0\0\x0d\x3f\0\0\0\x0e\x22\x02\0\0\x0e\x22\
\x02\0\0\x0e\xea\x01\0\0\0\x0f\x10\xc6\x01\0\0\x2e\x02\0\0\x03\x31\x09\x33\x02\
\0\0\x0d\x22\x02\0\0\x0e\x22\x02\0\0\x0e\x43\x02\0\0\0\x09\x48\x02\0\0\x11\x0c\
\xda\x01\0\0\x55\x02\0\0\x03\xce\x06\x09\x5a\x02\0\0\x0d\x3f\0\0\0\x0e\x22\x02\
\0\0\x0e\x22\x02\0\0\x0e\xbc\x01\0\0\x0e\xea\x01\0\0\0\x12\xc7\x01\0\0\x04\x02\
\x47\xb9\x13\xe8\x01\0\0\xff\x01\x13\xfe\x01\0\0\x80\x02\x13\x0f\x02\0\0\x80\
\x04\x13\x24\x02\0\0\x80\x08\x13\x38\x02\0\0\x80\x10\0\x14\0\0\0\0\0\0\0\0\xa0\
\x01\0\0\x01\x5a\x4c\x02\0\0\x01\x1f\x0f\x01\0\0\x15\0\0\0\0\x52\x02\0\0\x01\
\x1f\x22\x02\0\0\x16\x36\0\0\0\x6e\x01\0\0\x01\x22\xbc\x01\0\0\x16\x6e\0\0\0\
\x56\x02\0\0\x01\x23\x3f\0\0\0\x16\xa4\0\0\0\x5a\x02\0\0\x01\x21\xce\x01\0\0\0\
\0\x63\x6c\x61\x6e\x67\x20\x76\x65\x72\x73\x69\x6f\x6e\x20\x31\x32\x2e\x30\x2e\
\x31\x20\x28\x52\x65\x64\x20\x48\x61\x74\x20\x31\x32\x2e\x30\x2e\x31\x2d\x32\
\x2e\x6d\x6f\x64\x75\x6c\x65\x5f\x65\x6c\x38\x2e\x35\x2e\x30\x2b\x39\x37\x35\
\x2b\x35\x65\x35\x32\x66\x39\x39\x34\x29\0\x70\x72\x6f\x67\x73\x2f\x70\x65\x72\
\x66\x5f\x65\x76\x65\x6e\x74\x5f\x73\x74\x61\x63\x6b\x6d\x61\x70\x2e\x63\0\x2f\
\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\
\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x33\x34\x38\
\x2e\x37\x2e\x31\x2e\x65\x6c\x38\x5f\x35\x2f\x6c\x69\x6e\x75\x78\x2d\x34\x2e\
\x31\x38\x2e\x30\x2d\x33\x34\x38\x2e\x37\x2e\x31\x2e\x65\x6c\x38\x5f\x35\x2e\
\x78\x38\x36\x5f\x36\x34\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\
\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\0\x73\x74\x61\x63\
\x6b\x69\x64\x5f\x6b\x65\x72\x6e\x65\x6c\0\x6c\x6f\x6e\x67\x20\x69\x6e\x74\0\
\x73\x74\x61\x63\x6b\x69\x64\x5f\x75\x73\x65\x72\0\x73\x74\x61\x63\x6b\x5f\x6b\
\x65\x72\x6e\x65\x6c\0\x73\x74\x61\x63\x6b\x5f\x75\x73\x65\x72\0\x4c\x49\x43\
\x45\x4e\x53\x45\0\x63\x68\x61\x72\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\
\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x73\x74\x61\x63\x6b\x6d\x61\x70\0\x74\
\x79\x70\x65\0\x69\x6e\x74\0\x6d\x61\x78\x5f\x65\x6e\x74\x72\x69\x65\x73\0\x6b\
\x65\x79\x5f\x73\x69\x7a\x65\0\x76\x61\x6c\x75\x65\x5f\x73\x69\x7a\x65\0\x73\
\x74\x61\x63\x6b\x64\x61\x74\x61\x5f\x6d\x61\x70\0\x6b\x65\x79\0\x75\x6e\x73\
\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x5f\x5f\x75\x33\x32\0\x76\x61\x6c\x75\
\x65\0\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\x20\x75\x6e\x73\x69\x67\x6e\x65\x64\
\x20\x69\x6e\x74\0\x5f\x5f\x75\x36\x34\0\x73\x74\x61\x63\x6b\x5f\x74\x72\x61\
\x63\x65\x5f\x74\0\x62\x70\x66\x5f\x67\x65\x74\x5f\x73\x74\x61\x63\x6b\x69\x64\
\0\x62\x70\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\
\0\x62\x70\x66\x5f\x67\x65\x74\x5f\x73\x74\x61\x63\x6b\0\x42\x50\x46\x5f\x46\
\x5f\x53\x4b\x49\x50\x5f\x46\x49\x45\x4c\x44\x5f\x4d\x41\x53\x4b\0\x42\x50\x46\
\x5f\x46\x5f\x55\x53\x45\x52\x5f\x53\x54\x41\x43\x4b\0\x42\x50\x46\x5f\x46\x5f\
\x46\x41\x53\x54\x5f\x53\x54\x41\x43\x4b\x5f\x43\x4d\x50\0\x42\x50\x46\x5f\x46\
\x5f\x52\x45\x55\x53\x45\x5f\x53\x54\x41\x43\x4b\x49\x44\0\x42\x50\x46\x5f\x46\
\x5f\x55\x53\x45\x52\x5f\x42\x55\x49\x4c\x44\x5f\x49\x44\0\x6f\x6e\x63\x70\x75\
\0\x63\x74\x78\0\x76\x61\x6c\0\x74\x72\x61\x63\x65\0\x9f\xeb\x01\0\x18\0\0\0\0\
\0\0\0\x30\x03\0\0\x30\x03\0\0\x4e\x03\0\0\0\0\0\0\0\0\0\x02\x03\0\0\0\x01\0\0\
\0\0\0\0\x01\x04\0\0\0\x20\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\
\0\x07\0\0\0\x05\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\x02\x06\0\0\
\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\x02\
\x08\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x04\0\0\0\0\0\0\0\0\0\
\0\x02\x0a\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\xf8\x03\0\0\0\0\
\0\0\x04\0\0\x04\x20\0\0\0\x19\0\0\0\x01\0\0\0\0\0\0\0\x1e\0\0\0\x05\0\0\0\x40\
\0\0\0\x2a\0\0\0\x07\0\0\0\x80\0\0\0\x33\0\0\0\x09\0\0\0\xc0\0\0\0\x3e\0\0\0\0\
\0\0\x0e\x0b\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x0e\0\0\0\0\0\0\0\0\0\0\x03\0\0\
\0\0\x02\0\0\0\x04\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\x02\x10\0\0\0\0\0\0\0\0\0\0\
\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x12\0\0\0\x47\0\0\
\0\0\0\0\x08\x13\0\0\0\x4d\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\
\x02\x15\0\0\0\x5a\0\0\0\0\0\0\x08\x18\0\0\0\x68\0\0\0\0\0\0\x08\x17\0\0\0\x6e\
\0\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x16\0\0\0\x04\0\
\0\0\x7f\0\0\0\0\0\0\0\x04\0\0\x04\x20\0\0\0\x19\0\0\0\x0d\0\0\0\0\0\0\0\x1e\0\
\0\0\x0f\0\0\0\x40\0\0\0\x85\0\0\0\x11\0\0\0\x80\0\0\0\x89\0\0\0\x14\0\0\0\xc0\
\0\0\0\x8f\0\0\0\0\0\0\x0e\x19\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\
\0\x01\0\0\x0d\x02\0\0\0\x9d\0\0\0\x1b\0\0\0\xa1\0\0\0\x01\0\0\x0c\x1c\0\0\0\
\xf0\x02\0\0\0\0\0\x01\x08\0\0\0\x40\0\0\x01\xf9\x02\0\0\0\0\0\x0e\x1e\0\0\0\
\x01\0\0\0\x08\x03\0\0\0\0\0\x0e\x1e\0\0\0\x01\0\0\0\x15\x03\0\0\0\0\0\x0e\x1e\
\0\0\0\x01\0\0\0\x22\x03\0\0\0\0\0\x0e\x1e\0\0\0\x01\0\0\0\x2d\x03\0\0\0\0\0\
\x01\x01\0\0\0\x08\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\x23\0\0\0\x04\0\0\0\x04\0\
\0\0\x32\x03\0\0\0\0\0\x0e\x24\0\0\0\x01\0\0\0\x3a\x03\0\0\x04\0\0\x0f\0\0\0\0\
\x1f\0\0\0\0\0\0\0\x08\0\0\0\x20\0\0\0\0\0\0\0\x08\0\0\0\x21\0\0\0\0\0\0\0\x08\
\0\0\0\x22\0\0\0\0\0\0\0\x08\0\0\0\x40\x03\0\0\x02\0\0\x0f\0\0\0\0\x0c\0\0\0\0\
\0\0\0\x20\0\0\0\x1a\0\0\0\0\0\0\0\x20\0\0\0\x46\x03\0\0\x01\0\0\x0f\0\0\0\0\
\x25\0\0\0\0\0\0\0\x04\0\0\0\0\x69\x6e\x74\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\
\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x74\x79\x70\x65\0\x6d\x61\x78\
\x5f\x65\x6e\x74\x72\x69\x65\x73\0\x6b\x65\x79\x5f\x73\x69\x7a\x65\0\x76\x61\
\x6c\x75\x65\x5f\x73\x69\x7a\x65\0\x73\x74\x61\x63\x6b\x6d\x61\x70\0\x5f\x5f\
\x75\x33\x32\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x73\x74\x61\
\x63\x6b\x5f\x74\x72\x61\x63\x65\x5f\x74\0\x5f\x5f\x75\x36\x34\0\x6c\x6f\x6e\
\x67\x20\x6c\x6f\x6e\x67\x20\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\
\x6b\x65\x79\0\x76\x61\x6c\x75\x65\0\x73\x74\x61\x63\x6b\x64\x61\x74\x61\x5f\
\x6d\x61\x70\0\x63\x74\x78\0\x6f\x6e\x63\x70\x75\0\x70\x65\x72\x66\x5f\x65\x76\
\x65\x6e\x74\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\
\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x34\x2e\x31\x38\x2e\x30\
\x2d\x33\x34\x38\x2e\x37\x2e\x31\x2e\x65\x6c\x38\x5f\x35\x2f\x6c\x69\x6e\x75\
\x78\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x33\x34\x38\x2e\x37\x2e\x31\x2e\x65\x6c\
\x38\x5f\x35\x2e\x78\x38\x36\x5f\x36\x34\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\
\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\
\x2f\x70\x72\x6f\x67\x73\x2f\x70\x65\x72\x66\x5f\x65\x76\x65\x6e\x74\x5f\x73\
\x74\x61\x63\x6b\x6d\x61\x70\x2e\x63\0\x69\x6e\x74\x20\x6f\x6e\x63\x70\x75\x28\
\x76\x6f\x69\x64\x20\x2a\x63\x74\x78\x29\0\x09\x5f\x5f\x75\x33\x32\x20\x6b\x65\
\x79\x20\x3d\x20\x30\x3b\0\x09\x76\x61\x6c\x20\x3d\x20\x62\x70\x66\x5f\x67\x65\
\x74\x5f\x73\x74\x61\x63\x6b\x69\x64\x28\x63\x74\x78\x2c\x20\x26\x73\x74\x61\
\x63\x6b\x6d\x61\x70\x2c\x20\x30\x29\x3b\0\x09\x69\x66\x20\x28\x76\x61\x6c\x20\
\x3e\x20\x30\x29\0\x09\x09\x73\x74\x61\x63\x6b\x69\x64\x5f\x6b\x65\x72\x6e\x65\
\x6c\x20\x3d\x20\x32\x3b\0\x09\x76\x61\x6c\x20\x3d\x20\x62\x70\x66\x5f\x67\x65\
\x74\x5f\x73\x74\x61\x63\x6b\x69\x64\x28\x63\x74\x78\x2c\x20\x26\x73\x74\x61\
\x63\x6b\x6d\x61\x70\x2c\x20\x42\x50\x46\x5f\x46\x5f\x55\x53\x45\x52\x5f\x53\
\x54\x41\x43\x4b\x29\x3b\0\x09\x09\x73\x74\x61\x63\x6b\x69\x64\x5f\x75\x73\x65\
\x72\x20\x3d\x20\x32\x3b\0\x09\x74\x72\x61\x63\x65\x20\x3d\x20\x62\x70\x66\x5f\
\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\x28\x26\x73\x74\
\x61\x63\x6b\x64\x61\x74\x61\x5f\x6d\x61\x70\x2c\x20\x26\x6b\x65\x79\x29\x3b\0\
\x09\x69\x66\x20\x28\x21\x74\x72\x61\x63\x65\x29\0\x09\x76\x61\x6c\x20\x3d\x20\
\x62\x70\x66\x5f\x67\x65\x74\x5f\x73\x74\x61\x63\x6b\x28\x63\x74\x78\x2c\x20\
\x74\x72\x61\x63\x65\x2c\x20\x73\x69\x7a\x65\x6f\x66\x28\x73\x74\x61\x63\x6b\
\x5f\x74\x72\x61\x63\x65\x5f\x74\x29\x2c\x20\x30\x29\x3b\0\x09\x09\x73\x74\x61\
\x63\x6b\x5f\x6b\x65\x72\x6e\x65\x6c\x20\x3d\x20\x32\x3b\0\x09\x76\x61\x6c\x20\
\x3d\x20\x62\x70\x66\x5f\x67\x65\x74\x5f\x73\x74\x61\x63\x6b\x28\x63\x74\x78\
\x2c\x20\x74\x72\x61\x63\x65\x2c\x20\x73\x69\x7a\x65\x6f\x66\x28\x73\x74\x61\
\x63\x6b\x5f\x74\x72\x61\x63\x65\x5f\x74\x29\x2c\x20\x42\x50\x46\x5f\x46\x5f\
\x55\x53\x45\x52\x5f\x53\x54\x41\x43\x4b\x29\x3b\0\x09\x09\x73\x74\x61\x63\x6b\
\x5f\x75\x73\x65\x72\x20\x3d\x20\x32\x3b\0\x7d\0\x6c\x6f\x6e\x67\x20\x69\x6e\
\x74\0\x73\x74\x61\x63\x6b\x69\x64\x5f\x6b\x65\x72\x6e\x65\x6c\0\x73\x74\x61\
\x63\x6b\x69\x64\x5f\x75\x73\x65\x72\0\x73\x74\x61\x63\x6b\x5f\x6b\x65\x72\x6e\
\x65\x6c\0\x73\x74\x61\x63\x6b\x5f\x75\x73\x65\x72\0\x63\x68\x61\x72\0\x4c\x49\
\x43\x45\x4e\x53\x45\0\x2e\x64\x61\x74\x61\0\x2e\x6d\x61\x70\x73\0\x6c\x69\x63\
\x65\x6e\x73\x65\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x14\0\0\0\x14\0\0\0\x2c\x01\
\0\0\x40\x01\0\0\0\0\0\0\x08\0\0\0\xa7\0\0\0\x01\0\0\0\0\0\0\0\x1d\0\0\0\x10\0\
\0\0\xa7\0\0\0\x12\0\0\0\0\0\0\0\xb2\0\0\0\x3e\x01\0\0\0\x7c\0\0\x10\0\0\0\xb2\
\0\0\0\x53\x01\0\0\x08\x88\0\0\x18\0\0\0\xb2\0\0\0\x63\x01\0\0\x08\x94\0\0\x40\
\0\0\0\xb2\0\0\0\x8e\x01\0\0\x06\x98\0\0\x48\0\0\0\xb2\0\0\0\x9c\x01\0\0\x12\
\x9c\0\0\x68\0\0\0\xb2\0\0\0\xb2\x01\0\0\x08\xa0\0\0\x90\0\0\0\xb2\0\0\0\x8e\
\x01\0\0\x06\xa4\0\0\x98\0\0\0\xb2\0\0\0\xec\x01\0\0\x10\xa8\0\0\xc0\0\0\0\xb2\
\0\0\0\0\0\0\0\0\0\0\0\xc8\0\0\0\xb2\0\0\0\0\x02\0\0\x0a\xb0\0\0\xe8\0\0\0\xb2\
\0\0\0\x34\x02\0\0\x06\xb4\0\0\xf0\0\0\0\xb2\0\0\0\x41\x02\0\0\x08\xc0\0\0\x18\
\x01\0\0\xb2\0\0\0\x8e\x01\0\0\x06\xc4\0\0\x20\x01\0\0\xb2\0\0\0\x7d\x02\0\0\
\x10\xc8\0\0\x40\x01\0\0\xb2\0\0\0\x91\x02\0\0\x08\xd0\0\0\x68\x01\0\0\xb2\0\0\
\0\x8e\x01\0\0\x06\xd4\0\0\x70\x01\0\0\xb2\0\0\0\xdc\x02\0\0\x0e\xd8\0\0\x90\
\x01\0\0\xb2\0\0\0\xee\x02\0\0\x01\xe4\0\0\0\0\0\x0c\0\0\0\xff\xff\xff\xff\x04\
\0\x08\0\x08\x7c\x0b\0\x14\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa0\x01\0\0\0\0\0\0\
\xc4\0\0\0\x04\0\x75\0\0\0\x08\x01\x01\xfb\x0e\x0d\0\x01\x01\x01\x01\0\0\0\x01\
\0\0\x01\x70\x72\x6f\x67\x73\0\x74\x6f\x6f\x6c\x73\x2f\x69\x6e\x63\x6c\x75\x64\
\x65\0\x74\x6f\x6f\x6c\x73\x2f\x69\x6e\x63\x6c\x75\x64\x65\x2f\x62\x70\x66\0\0\
\x70\x65\x72\x66\x5f\x65\x76\x65\x6e\x74\x5f\x73\x74\x61\x63\x6b\x6d\x61\x70\
\x2e\x63\0\x01\0\0\x76\x6d\x6c\x69\x6e\x75\x78\x2e\x68\0\x02\0\0\x62\x70\x66\
\x5f\x68\x65\x6c\x70\x65\x72\x5f\x64\x65\x66\x73\x2e\x68\0\x03\0\0\0\0\x09\x02\
\0\0\0\0\0\0\0\0\x03\x1f\x01\x05\x08\x0a\x30\x23\x05\x06\x59\x05\x12\x21\x05\
\x08\x4b\x05\x06\x59\x05\x10\x21\x06\x03\x56\x4a\x05\x0a\x06\x03\x2c\x2e\x05\
\x06\x4b\x05\x08\x23\x05\x06\x59\x05\x10\x21\x05\x08\x4c\x05\x06\x59\x05\x0e\
\x21\x05\x01\x4d\x02\x02\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\xe5\0\0\0\x04\0\xf1\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x37\x01\0\0\0\0\
\x03\0\x68\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\x01\0\0\0\0\x03\0\xb8\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x29\x01\0\0\0\0\x03\0\x40\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x22\x01\0\0\0\0\x03\0\x90\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x03\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x03\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x0c\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x11\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x03\0\x13\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x1a\x01\0\0\x11\0\
\x07\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x0f\0\0\0\x12\0\x03\0\0\0\0\0\0\0\0\0\
\xa0\x01\0\0\0\0\0\0\x87\0\0\0\x11\0\x05\0\x10\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\x48\0\0\0\x11\0\x05\0\x18\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\x69\0\0\0\x11\0\x06\
\0\x20\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x94\0\0\0\x11\0\x05\0\0\0\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\x53\0\0\0\x11\0\x05\0\x08\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\x60\0\0\0\x11\0\x06\0\0\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x01\
\0\0\0\x13\0\0\0\x48\0\0\0\0\0\0\0\x01\0\0\0\x11\0\0\0\x70\0\0\0\0\0\0\0\x01\0\
\0\0\x13\0\0\0\x98\0\0\0\0\0\0\0\x01\0\0\0\x12\0\0\0\xc8\0\0\0\0\0\0\0\x01\0\0\
\0\x10\0\0\0\x20\x01\0\0\0\0\0\0\x01\0\0\0\x0e\0\0\0\x70\x01\0\0\0\0\0\0\x01\0\
\0\0\x0f\0\0\0\x06\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\x0c\0\0\0\0\0\0\0\x0a\0\0\
\0\x09\0\0\0\x12\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x16\0\0\0\0\0\0\0\x0a\0\0\0\
\x0b\0\0\0\x1a\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x1e\0\0\0\0\0\0\0\x01\0\0\0\
\x06\0\0\0\x2b\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x37\0\0\0\0\0\0\0\x01\0\0\0\
\x11\0\0\0\x40\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x47\0\0\0\0\0\0\0\x0a\0\0\0\
\x09\0\0\0\x53\0\0\0\0\0\0\0\x01\0\0\0\x12\0\0\0\x5c\0\0\0\0\0\0\0\x0a\0\0\0\
\x09\0\0\0\x68\0\0\0\0\0\0\0\x01\0\0\0\x0e\0\0\0\x71\0\0\0\0\0\0\0\x0a\0\0\0\
\x09\0\0\0\x7d\0\0\0\0\0\0\0\x01\0\0\0\x0f\0\0\0\x86\0\0\0\0\0\0\0\x0a\0\0\0\
\x09\0\0\0\x92\0\0\0\0\0\0\0\x01\0\0\0\x0c\0\0\0\xa7\0\0\0\0\0\0\0\x0a\0\0\0\
\x09\0\0\0\xae\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xb5\0\0\0\0\0\0\0\x0a\0\0\0\
\x09\0\0\0\xc1\0\0\0\0\0\0\0\x01\0\0\0\x13\0\0\0\xce\0\0\0\0\0\0\0\x0a\0\0\0\
\x09\0\0\0\xda\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xe6\0\0\0\0\0\0\0\x0a\0\0\0\
\x09\0\0\0\xf2\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x10\x01\0\0\0\0\0\0\x0a\0\0\0\
\x09\0\0\0\x4c\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x58\x01\0\0\0\0\0\0\x01\0\0\
\0\x10\0\0\0\x65\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x71\x01\0\0\0\0\0\0\x0a\0\
\0\0\x09\0\0\0\x7d\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x89\x01\0\0\0\0\0\0\x0a\
\0\0\0\x09\0\0\0\xc1\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xc8\x01\0\0\0\0\0\0\
\x0a\0\0\0\x09\0\0\0\xd8\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xef\x01\0\0\0\0\0\
\0\x0a\0\0\0\x09\0\0\0\xf6\x01\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xfd\x01\0\0\0\0\
\0\0\x0a\0\0\0\x09\0\0\0\x24\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x4a\x02\0\0\0\
\0\0\0\x0a\0\0\0\x09\0\0\0\x7e\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x85\x02\0\0\
\0\0\0\0\x0a\0\0\0\x09\0\0\0\x8c\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x93\x02\0\
\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x9a\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xa2\x02\
\0\0\0\0\0\0\x01\0\0\0\x06\0\0\0\xb0\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\xbb\
\x02\0\0\0\0\0\0\x0a\0\0\0\x07\0\0\0\xbf\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\
\xca\x02\0\0\0\0\0\0\x0a\0\0\0\x07\0\0\0\xce\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\
\0\xd9\x02\0\0\0\0\0\0\x0a\0\0\0\x07\0\0\0\xdd\x02\0\0\0\0\0\0\x0a\0\0\0\x09\0\
\0\0\xe8\x02\0\0\0\0\0\0\x0a\0\0\0\x07\0\0\0\xec\x02\0\0\0\0\0\0\x0a\0\0\0\x09\
\0\0\0\xe0\x02\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\xec\x02\0\0\0\0\0\0\0\0\0\0\x12\0\
\0\0\xf8\x02\0\0\0\0\0\0\0\0\0\0\x0e\0\0\0\x04\x03\0\0\0\0\0\0\0\0\0\0\x0f\0\0\
\0\x1c\x03\0\0\0\0\0\0\0\0\0\0\x13\0\0\0\x28\x03\0\0\0\0\0\0\0\0\0\0\x10\0\0\0\
\x40\x03\0\0\0\0\0\0\0\0\0\0\x0c\0\0\0\x2c\0\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\x40\
\0\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\x50\0\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\x60\0\0\0\
\0\0\0\0\0\0\0\0\x06\0\0\0\x70\0\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\x80\0\0\0\0\0\0\
\0\0\0\0\0\x06\0\0\0\x90\0\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\xa0\0\0\0\0\0\0\0\0\0\
\0\0\x06\0\0\0\xb0\0\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\xc0\0\0\0\0\0\0\0\0\0\0\0\
\x06\0\0\0\xd0\0\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\xe0\0\0\0\0\0\0\0\0\0\0\0\x06\0\
\0\0\xf0\0\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\
\x10\x01\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\x20\x01\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\
\x30\x01\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\x40\x01\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\
\x50\x01\0\0\0\0\0\0\0\0\0\0\x06\0\0\0\x14\0\0\0\0\0\0\0\x0a\0\0\0\x0a\0\0\0\
\x18\0\0\0\0\0\0\0\x01\0\0\0\x06\0\0\0\x82\0\0\0\0\0\0\0\x01\0\0\0\x06\0\0\0\
\x0d\x13\x10\x0c\0\x2e\x64\x65\x62\x75\x67\x5f\x61\x62\x62\x72\x65\x76\0\x6f\
\x6e\x63\x70\x75\0\x2e\x74\x65\x78\x74\0\x2e\x72\x65\x6c\x2e\x42\x54\x46\x2e\
\x65\x78\x74\0\x2e\x72\x65\x6c\x70\x65\x72\x66\x5f\x65\x76\x65\x6e\x74\0\x2e\
\x6d\x61\x70\x73\0\x2e\x64\x65\x62\x75\x67\x5f\x73\x74\x72\0\x73\x74\x61\x63\
\x6b\x5f\x75\x73\x65\x72\0\x73\x74\x61\x63\x6b\x69\x64\x5f\x75\x73\x65\x72\0\
\x73\x74\x61\x63\x6b\x6d\x61\x70\0\x73\x74\x61\x63\x6b\x64\x61\x74\x61\x5f\x6d\
\x61\x70\0\x2e\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\x69\x6e\x66\x6f\0\x73\
\x74\x61\x63\x6b\x5f\x6b\x65\x72\x6e\x65\x6c\0\x73\x74\x61\x63\x6b\x69\x64\x5f\
\x6b\x65\x72\x6e\x65\x6c\0\x2e\x6c\x6c\x76\x6d\x5f\x61\x64\x64\x72\x73\x69\x67\
\0\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\
\x6c\x69\x6e\x65\0\x2e\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\x66\x72\x61\x6d\
\x65\0\x2e\x64\x65\x62\x75\x67\x5f\x6c\x6f\x63\0\x70\x65\x72\x66\x5f\x65\x76\
\x65\x6e\x74\x5f\x73\x74\x61\x63\x6b\x6d\x61\x70\x2e\x63\0\x2e\x73\x74\x72\x74\
\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x2e\x64\x61\x74\x61\0\x2e\x72\x65\x6c\
\x2e\x42\x54\x46\0\x4c\x49\x43\x45\x4e\x53\x45\0\x4c\x42\x42\x30\x5f\x39\0\x4c\
\x42\x42\x30\x5f\x37\0\x4c\x42\x42\x30\x5f\x34\0\x4c\x42\x42\x30\x5f\x32\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xfb\0\0\0\x03\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe4\x19\0\0\0\0\0\0\x3e\x01\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x15\0\0\0\x01\0\0\0\x06\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x2c\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x40\0\0\0\0\0\0\0\xa0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x28\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\x14\0\0\0\
\0\0\0\x70\0\0\0\0\0\0\0\x16\0\0\0\x03\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\
\0\x0b\x01\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe0\x01\0\0\0\0\0\0\
\x20\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x37\0\0\0\
\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\x40\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb1\0\0\0\x01\0\0\0\x03\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\x02\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xda\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x44\x02\0\0\0\0\0\0\xc7\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0b\
\x03\0\0\0\0\0\0\x04\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x7b\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0f\x04\0\0\0\0\0\
\0\xf8\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x77\0\
\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa0\x14\0\0\0\0\0\0\x70\x03\0\0\
\0\0\0\0\x16\0\0\0\x0a\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x3d\0\0\0\x01\
\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x07\x07\0\0\0\0\0\0\x60\x02\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x15\x01\0\0\x01\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x67\x09\0\0\0\0\0\0\x96\x06\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\x01\0\0\x09\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x10\x18\0\0\0\0\0\0\x70\0\0\0\0\0\0\0\x16\0\0\0\x0d\0\0\0\
\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x1f\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\xfd\x0f\0\0\0\0\0\0\x60\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x1b\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x80\
\x18\0\0\0\0\0\0\x30\x01\0\0\0\0\0\0\x16\0\0\0\x0f\0\0\0\x08\0\0\0\0\0\0\0\x10\
\0\0\0\0\0\0\0\xcd\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x60\x11\0\0\
\0\0\0\0\x28\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xc9\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb0\x19\0\0\0\0\0\0\x20\0\
\0\0\0\0\0\0\x16\0\0\0\x11\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xbd\0\0\0\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x88\x11\0\0\0\0\0\0\xc8\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb9\0\0\0\x09\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\xd0\x19\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x16\0\0\0\x13\
\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xa3\0\0\0\x03\x4c\xff\x6f\0\0\0\x80\
\0\0\0\0\0\0\0\0\0\0\0\0\xe0\x19\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x16\0\0\0\0\0\0\
\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\x01\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x50\x12\0\0\0\0\0\0\xe0\x01\0\0\0\0\0\0\x01\0\0\0\x0c\0\0\0\x08\0\
\0\0\0\0\0\0\x18\0\0\0\0\0\0\0";

	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return -1;
}

#endif /* __PERF_EVENT_STACKMAP_SKEL_H__ */
