/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __TEST_AUTOLOAD_SKEL_H__
#define __TEST_AUTOLOAD_SKEL_H__

#include <stdlib.h>
#include <bpf/libbpf.h>

struct test_autoload {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *bss;
	} maps;
	struct {
		struct bpf_program *prog1;
		struct bpf_program *prog2;
		struct bpf_program *prog3;
	} progs;
	struct {
		struct bpf_link *prog1;
		struct bpf_link *prog2;
		struct bpf_link *prog3;
	} links;
	struct test_autoload__bss {
		bool prog1_called;
		bool prog2_called;
		bool prog3_called;
	} *bss;
};

static void
test_autoload__destroy(struct test_autoload *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
test_autoload__create_skeleton(struct test_autoload *obj);

static inline struct test_autoload *
test_autoload__open_opts(const struct bpf_object_open_opts *opts)
{
	struct test_autoload *obj;

	obj = (struct test_autoload *)calloc(1, sizeof(*obj));
	if (!obj)
		return NULL;
	if (test_autoload__create_skeleton(obj))
		goto err;
	if (bpf_object__open_skeleton(obj->skeleton, opts))
		goto err;

	return obj;
err:
	test_autoload__destroy(obj);
	return NULL;
}

static inline struct test_autoload *
test_autoload__open(void)
{
	return test_autoload__open_opts(NULL);
}

static inline int
test_autoload__load(struct test_autoload *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct test_autoload *
test_autoload__open_and_load(void)
{
	struct test_autoload *obj;

	obj = test_autoload__open();
	if (!obj)
		return NULL;
	if (test_autoload__load(obj)) {
		test_autoload__destroy(obj);
		return NULL;
	}
	return obj;
}

static inline int
test_autoload__attach(struct test_autoload *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
test_autoload__detach(struct test_autoload *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline int
test_autoload__create_skeleton(struct test_autoload *obj)
{
	struct bpf_object_skeleton *s;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)
		return -1;
	obj->skeleton = s;

	s->sz = sizeof(*s);
	s->name = "test_autoload";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 1;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps)
		goto err;

	s->maps[0].name = "test_aut.bss";
	s->maps[0].map = &obj->maps.bss;
	s->maps[0].mmaped = (void **)&obj->bss;

	/* programs */
	s->prog_cnt = 3;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs)
		goto err;

	s->progs[0].name = "prog1";
	s->progs[0].prog = &obj->progs.prog1;
	s->progs[0].link = &obj->links.prog1;

	s->progs[1].name = "prog2";
	s->progs[1].prog = &obj->progs.prog2;
	s->progs[1].link = &obj->links.prog2;

	s->progs[2].name = "prog3";
	s->progs[2].prog = &obj->progs.prog3;
	s->progs[2].link = &obj->links.prog3;

	s->data_sz = 6592;
	s->data = (void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x80\x12\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x1d\0\
\x01\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x02\0\0\x01\0\0\0\x73\x21\0\0\0\
\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xb7\x02\0\0\x01\0\0\0\x73\x21\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\
\xb7\x02\0\0\x7b\0\0\0\x63\x21\0\0\0\0\0\0\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xb7\x02\0\0\x01\0\0\0\x73\x21\0\0\0\0\0\0\xb7\0\0\0\0\0\0\0\x95\0\0\0\0\0\0\0\
\x47\x50\x4c\0\xff\xff\xff\xff\xff\xff\xff\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x20\0\0\0\0\0\0\0\x01\0\x51\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xff\xff\xff\xff\
\xff\xff\xff\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x01\0\x51\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x11\x01\x25\x0e\x13\x05\x03\x0e\x10\x17\x1b\
\x0e\x11\x01\x55\x17\0\0\x02\x34\0\x03\x0e\x49\x13\x3f\x19\x3a\x0b\x3b\x0b\x02\
\x18\0\0\x03\x16\0\x49\x13\x03\x0e\x3a\x0b\x3b\x0b\0\0\x04\x24\0\x03\x0e\x3e\
\x0b\x0b\x0b\0\0\x05\x01\x01\x49\x13\0\0\x06\x21\0\x49\x13\x37\x0b\0\0\x07\x24\
\0\x03\x0e\x0b\x0b\x3e\x0b\0\0\x08\x04\x01\x49\x13\x0b\x0b\x3a\x0b\x3b\x0b\0\0\
\x09\x28\0\x03\x0e\x1c\x0f\0\0\x0a\x0f\0\0\0\x0b\x2e\x01\x11\x01\x12\x06\x40\
\x18\x97\x42\x19\x03\x0e\x3a\x0b\x3b\x0b\x27\x19\x49\x13\x3f\x19\0\0\x0c\x05\0\
\x03\x0e\x3a\x0b\x3b\x0b\x49\x13\0\0\x0d\x05\0\x02\x17\x03\x0e\x3a\x0b\x3b\x0b\
\x49\x13\0\0\x0e\x34\0\x02\x17\x03\x0e\x3a\x0b\x3b\x0b\x49\x13\0\0\x0f\x0f\0\
\x49\x13\0\0\x10\x26\0\0\0\x11\x13\x01\x03\x0e\x0b\x0b\x3a\x0b\x3b\x0b\0\0\x12\
\x0d\0\x03\x0e\x49\x13\x3a\x0b\x3b\x0b\x38\x0b\0\0\0\x6d\x01\0\0\x04\0\0\0\0\0\
\x08\x01\0\0\0\0\x0c\0\x44\0\0\0\0\0\0\0\x5a\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\
\xca\0\0\0\x3f\0\0\0\x02\x09\x09\x03\0\0\0\0\0\0\0\0\x03\x4a\0\0\0\xdd\0\0\0\
\x01\x51\x04\xd7\0\0\0\x02\x01\x02\xe2\0\0\0\x3f\0\0\0\x02\x0a\x09\x03\0\0\0\0\
\0\0\0\0\x02\xef\0\0\0\x3f\0\0\0\x02\x0b\x09\x03\0\0\0\0\0\0\0\0\x02\xfc\0\0\0\
\x90\0\0\0\x02\x28\x09\x03\0\0\0\0\0\0\0\0\x05\x9c\0\0\0\x06\xa3\0\0\0\x04\0\
\x04\x05\x01\0\0\x06\x01\x07\x0a\x01\0\0\x08\x07\x08\xbf\0\0\0\x04\x01\x28\x09\
\x2b\x01\0\0\0\x09\x31\x01\0\0\x01\0\x04\x1e\x01\0\0\x07\x04\x0a\x0b\0\0\0\0\0\
\0\0\0\x30\0\0\0\x01\x5a\x36\x01\0\0\x02\x0e\x49\x01\0\0\x0c\x4c\x01\0\0\x02\
\x0e\x50\x01\0\0\0\x0b\0\0\0\0\0\0\0\0\x30\0\0\0\x01\x5a\x40\x01\0\0\x02\x15\
\x49\x01\0\0\x0c\x4c\x01\0\0\x02\x15\x50\x01\0\0\0\x0b\0\0\0\0\0\0\0\0\x40\0\0\
\0\x01\x5a\x46\x01\0\0\x02\x20\x49\x01\0\0\x0d\0\0\0\0\x4c\x01\0\0\x02\x20\x50\
\x01\0\0\x0e\x33\0\0\0\x50\x01\0\0\x02\x22\x56\x01\0\0\0\x04\x3c\x01\0\0\x05\
\x04\x0f\x55\x01\0\0\x10\x0f\x5b\x01\0\0\x11\x5e\x01\0\0\x04\x02\x1b\x12\x55\
\x01\0\0\x49\x01\0\0\x02\x1c\0\0\0\0\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x63\x6c\x61\x6e\x67\x20\x76\x65\x72\x73\x69\x6f\x6e\x20\x31\x32\
\x2e\x30\x2e\x31\x20\x28\x52\x65\x64\x20\x48\x61\x74\x20\x31\x32\x2e\x30\x2e\
\x31\x2d\x32\x2e\x6d\x6f\x64\x75\x6c\x65\x5f\x65\x6c\x38\x2e\x35\x2e\x30\x2b\
\x39\x37\x35\x2b\x35\x65\x35\x32\x66\x39\x39\x34\x29\0\x70\x72\x6f\x67\x73\x2f\
\x74\x65\x73\x74\x5f\x61\x75\x74\x6f\x6c\x6f\x61\x64\x2e\x63\0\x2f\x62\x75\x69\
\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\
\x65\x72\x6e\x65\x6c\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x33\x34\x38\x2e\x37\x2e\
\x31\x2e\x65\x6c\x38\x5f\x35\x2f\x6c\x69\x6e\x75\x78\x2d\x34\x2e\x31\x38\x2e\
\x30\x2d\x33\x34\x38\x2e\x37\x2e\x31\x2e\x65\x6c\x38\x5f\x35\x2e\x78\x38\x36\
\x5f\x36\x34\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\
\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\0\x70\x72\x6f\x67\x31\x5f\x63\
\x61\x6c\x6c\x65\x64\0\x5f\x42\x6f\x6f\x6c\0\x62\x6f\x6f\x6c\0\x70\x72\x6f\x67\
\x32\x5f\x63\x61\x6c\x6c\x65\x64\0\x70\x72\x6f\x67\x33\x5f\x63\x61\x6c\x6c\x65\
\x64\0\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x63\x68\x61\x72\0\x5f\x5f\x41\x52\x52\
\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x75\x6e\x73\x69\x67\
\x6e\x65\x64\x20\x69\x6e\x74\0\x66\x61\x6c\x73\x65\0\x74\x72\x75\x65\0\x70\x72\
\x6f\x67\x31\0\x69\x6e\x74\0\x70\x72\x6f\x67\x32\0\x70\x72\x6f\x67\x33\0\x63\
\x74\x78\0\x66\x61\x6b\x65\0\x77\x68\x61\x74\x65\x76\x65\x72\0\x66\x61\x6b\x65\
\x5f\x6b\x65\x72\x6e\x65\x6c\x5f\x73\x74\x72\x75\x63\x74\0\x9f\xeb\x01\0\x18\0\
\0\0\0\0\0\0\x7c\x01\0\0\x7c\x01\0\0\xef\x01\0\0\0\0\0\0\0\0\0\x02\x02\0\0\0\0\
\0\0\0\0\0\0\x0a\0\0\0\0\0\0\0\0\x01\0\0\x0d\x04\0\0\0\x01\0\0\0\x01\0\0\0\x05\
\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\x01\x09\0\0\0\x01\0\0\x0c\x03\0\0\0\0\0\0\0\
\x01\0\0\x0d\x04\0\0\0\x01\0\0\0\x01\0\0\0\xc7\0\0\0\x01\0\0\x0c\x06\0\0\0\0\0\
\0\0\x01\0\0\x0d\x04\0\0\0\x01\0\0\0\x01\0\0\0\xf3\0\0\0\x01\0\0\x0c\x08\0\0\0\
\x41\x01\0\0\x01\0\0\x04\x04\0\0\0\x54\x01\0\0\x04\0\0\0\0\0\0\0\x8e\x01\0\0\0\
\0\0\x08\x0c\0\0\0\x93\x01\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x04\x99\x01\0\0\0\0\
\0\x0e\x0b\0\0\0\x01\0\0\0\xa6\x01\0\0\0\0\0\x0e\x0b\0\0\0\x01\0\0\0\xb3\x01\0\
\0\0\0\0\x0e\x0b\0\0\0\x01\0\0\0\xc0\x01\0\0\0\0\0\x01\x01\0\0\0\x08\0\0\x01\0\
\0\0\0\0\0\0\x03\0\0\0\0\x10\0\0\0\x12\0\0\0\x04\0\0\0\xc5\x01\0\0\0\0\0\x01\
\x04\0\0\0\x20\0\0\0\xd9\x01\0\0\0\0\0\x0e\x11\0\0\0\x01\0\0\0\xe2\x01\0\0\x03\
\0\0\x0f\0\0\0\0\x0d\0\0\0\0\0\0\0\x01\0\0\0\x0e\0\0\0\0\0\0\0\x01\0\0\0\x0f\0\
\0\0\0\0\0\0\x01\0\0\0\xe7\x01\0\0\x01\0\0\x0f\0\0\0\0\x13\0\0\0\0\0\0\0\x04\0\
\0\0\0\x63\x74\x78\0\x69\x6e\x74\0\x70\x72\x6f\x67\x31\0\x72\x61\x77\x5f\x74\
\x70\x2f\x73\x79\x73\x5f\x65\x6e\x74\x65\x72\0\x2f\x62\x75\x69\x6c\x64\x64\x69\
\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\
\x6c\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x33\x34\x38\x2e\x37\x2e\x31\x2e\x65\x6c\
\x38\x5f\x35\x2f\x6c\x69\x6e\x75\x78\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x33\x34\
\x38\x2e\x37\x2e\x31\x2e\x65\x6c\x38\x5f\x35\x2e\x78\x38\x36\x5f\x36\x34\x2f\
\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\
\x65\x73\x74\x73\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x74\x65\x73\x74\
\x5f\x61\x75\x74\x6f\x6c\x6f\x61\x64\x2e\x63\0\x09\x70\x72\x6f\x67\x31\x5f\x63\
\x61\x6c\x6c\x65\x64\x20\x3d\x20\x74\x72\x75\x65\x3b\0\x09\x72\x65\x74\x75\x72\
\x6e\x20\x30\x3b\0\x70\x72\x6f\x67\x32\0\x72\x61\x77\x5f\x74\x70\x2f\x73\x79\
\x73\x5f\x65\x78\x69\x74\0\x09\x70\x72\x6f\x67\x32\x5f\x63\x61\x6c\x6c\x65\x64\
\x20\x3d\x20\x74\x72\x75\x65\x3b\0\x70\x72\x6f\x67\x33\0\x66\x65\x6e\x74\x72\
\x79\x2f\x75\x6e\x65\x78\x69\x73\x74\x69\x6e\x67\x2d\x6b\x70\x72\x6f\x62\x65\
\x2d\x77\x69\x6c\x6c\x2d\x66\x61\x69\x6c\x2d\x69\x66\x2d\x6c\x6f\x61\x64\x65\
\x64\0\x69\x6e\x74\x20\x70\x72\x6f\x67\x33\x28\x63\x6f\x6e\x73\x74\x20\x76\x6f\
\x69\x64\x20\x2a\x63\x74\x78\x29\0\x66\x61\x6b\x65\x5f\x6b\x65\x72\x6e\x65\x6c\
\x5f\x73\x74\x72\x75\x63\x74\0\x77\x68\x61\x74\x65\x76\x65\x72\0\x30\x3a\x30\0\
\x09\x66\x61\x6b\x65\x2d\x3e\x77\x68\x61\x74\x65\x76\x65\x72\x20\x3d\x20\x31\
\x32\x33\x3b\0\x09\x70\x72\x6f\x67\x33\x5f\x63\x61\x6c\x6c\x65\x64\x20\x3d\x20\
\x74\x72\x75\x65\x3b\0\x62\x6f\x6f\x6c\0\x5f\x42\x6f\x6f\x6c\0\x70\x72\x6f\x67\
\x31\x5f\x63\x61\x6c\x6c\x65\x64\0\x70\x72\x6f\x67\x32\x5f\x63\x61\x6c\x6c\x65\
\x64\0\x70\x72\x6f\x67\x33\x5f\x63\x61\x6c\x6c\x65\x64\0\x63\x68\x61\x72\0\x5f\
\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\x5f\0\x5f\
\x6c\x69\x63\x65\x6e\x73\x65\0\x2e\x62\x73\x73\0\x6c\x69\x63\x65\x6e\x73\x65\0\
\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x34\0\0\0\x34\0\0\0\x9c\0\0\0\xd0\0\0\0\x1c\0\
\0\0\x08\0\0\0\x0f\0\0\0\x01\0\0\0\0\0\0\0\x05\0\0\0\xcd\0\0\0\x01\0\0\0\0\0\0\
\0\x07\0\0\0\xf9\0\0\0\x01\0\0\0\0\0\0\0\x09\0\0\0\x10\0\0\0\x0f\0\0\0\x02\0\0\
\0\0\0\0\0\x20\0\0\0\xa6\0\0\0\x0f\x40\0\0\x20\0\0\0\x20\0\0\0\xbc\0\0\0\x02\
\x44\0\0\xcd\0\0\0\x02\0\0\0\0\0\0\0\x20\0\0\0\xdd\0\0\0\x0f\x5c\0\0\x20\0\0\0\
\x20\0\0\0\xbc\0\0\0\x02\x60\0\0\xf9\0\0\0\x04\0\0\0\0\0\0\0\x20\0\0\0\x26\x01\
\0\0\0\x80\0\0\x08\0\0\0\x20\0\0\0\x61\x01\0\0\x11\x8c\0\0\x10\0\0\0\x20\0\0\0\
\x78\x01\0\0\x0f\x90\0\0\x30\0\0\0\x20\0\0\0\xbc\0\0\0\x02\x94\0\0\x10\0\0\0\
\xf9\0\0\0\x01\0\0\0\x08\0\0\0\x0a\0\0\0\x5d\x01\0\0\0\0\0\0\0\0\0\0\0\x0c\0\0\
\0\xff\xff\xff\xff\x04\0\x08\0\x08\x7c\x0b\0\x14\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x30\0\0\0\0\0\0\0\x14\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\x14\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\xad\0\0\0\x04\0\x48\0\0\0\x08\x01\
\x01\xfb\x0e\x0d\0\x01\x01\x01\x01\0\0\0\x01\0\0\x01\x74\x6f\x6f\x6c\x73\x2f\
\x69\x6e\x63\x6c\x75\x64\x65\0\x70\x72\x6f\x67\x73\0\0\x76\x6d\x6c\x69\x6e\x75\
\x78\x2e\x68\0\x01\0\0\x74\x65\x73\x74\x5f\x61\x75\x74\x6f\x6c\x6f\x61\x64\x2e\
\x63\0\x02\0\0\0\x04\x02\0\x09\x02\0\0\0\0\0\0\0\0\x03\x0e\x01\x05\x0f\x0a\x13\
\x05\x02\x4b\x02\x02\0\x01\x01\x04\x02\0\x09\x02\0\0\0\0\0\0\0\0\x03\x15\x01\
\x05\x0f\x0a\x13\x05\x02\x4b\x02\x02\0\x01\x01\x04\x02\0\x09\x02\0\0\0\0\0\0\0\
\0\x03\x20\x01\x05\x11\x0a\x22\x05\x0f\x21\x06\x03\x5c\x2e\x03\x24\x20\x05\x02\
\x06\x21\x02\x02\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x1c\x01\0\0\x04\0\xf1\xff\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x05\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x07\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x03\0\x0b\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x0d\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x03\0\x12\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x17\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x19\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x8b\0\0\
\0\x11\0\x0a\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x51\x01\0\0\x12\0\x03\0\0\0\0\
\0\0\0\0\0\x30\0\0\0\0\0\0\0\xcf\0\0\0\x11\0\x09\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\
\0\0\0\x4b\x01\0\0\x12\0\x05\0\0\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\xc2\0\0\0\x11\
\0\x09\0\x01\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x45\x01\0\0\x12\0\x07\0\0\0\0\0\0\
\0\0\0\x40\0\0\0\0\0\0\0\xb5\0\0\0\x11\0\x09\0\x02\0\0\0\0\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x0d\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x0f\0\0\0\
\x10\0\0\0\0\0\0\0\x01\0\0\0\x11\0\0\0\x08\0\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\
\x3b\0\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\x06\0\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\
\x0c\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\x12\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\
\x16\0\0\0\0\0\0\0\x0a\0\0\0\x0a\0\0\0\x1a\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\
\x26\0\0\0\0\0\0\0\x0a\0\0\0\x07\0\0\0\x2b\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\
\x37\0\0\0\0\0\0\0\x01\0\0\0\x0d\0\0\0\x44\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\
\x4b\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\x52\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\
\x5e\0\0\0\0\0\0\0\x01\0\0\0\x0f\0\0\0\x67\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\
\x73\0\0\0\0\0\0\0\x01\0\0\0\x11\0\0\0\x7c\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\
\x88\0\0\0\0\0\0\0\x01\0\0\0\x0b\0\0\0\x9d\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\
\xa4\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\xb3\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\
\xb9\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\xc0\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\
\xc8\0\0\0\0\0\0\0\x01\0\0\0\x02\0\0\0\xd6\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\
\xe1\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\xed\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\
\xfb\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\x06\x01\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\
\x12\x01\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\x20\x01\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\
\0\x2b\x01\0\0\0\0\0\0\x0a\0\0\0\x05\0\0\0\x2f\x01\0\0\0\0\0\0\x0a\0\0\0\x08\0\
\0\0\x3a\x01\0\0\0\0\0\0\x0a\0\0\0\x05\0\0\0\x3e\x01\0\0\0\0\0\0\x0a\0\0\0\x08\
\0\0\0\x4a\x01\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\x5c\x01\0\0\0\0\0\0\x0a\0\0\0\
\x08\0\0\0\x64\x01\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\
\x02\0\0\0\x08\0\0\0\0\0\0\0\x01\0\0\0\x02\0\0\0\x10\0\0\0\0\0\0\0\x01\0\0\0\
\x03\0\0\0\x18\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\x20\0\0\0\0\0\0\0\x01\0\0\0\
\x04\0\0\0\x28\0\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\x5c\x01\0\0\0\0\0\0\0\0\0\0\
\x0d\0\0\0\x68\x01\0\0\0\0\0\0\0\0\0\0\x0f\0\0\0\x74\x01\0\0\0\0\0\0\0\0\0\0\
\x11\0\0\0\x8c\x01\0\0\0\0\0\0\0\0\0\0\x0b\0\0\0\x2c\0\0\0\0\0\0\0\0\0\0\0\x02\
\0\0\0\x3c\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x4c\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\
\x60\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x70\0\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\x88\0\
\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x98\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\xb0\0\0\0\0\
\0\0\0\0\0\0\0\x04\0\0\0\xc0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\xd0\0\0\0\0\0\0\0\
\0\0\0\0\x04\0\0\0\xe0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\xfc\0\0\0\0\0\0\0\0\0\0\
\0\x04\0\0\0\x14\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x18\0\0\0\0\0\0\0\x01\0\0\0\
\x02\0\0\0\x2c\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x30\0\0\0\0\0\0\0\x01\0\0\0\
\x03\0\0\0\x44\0\0\0\0\0\0\0\x0a\0\0\0\x09\0\0\0\x48\0\0\0\0\0\0\0\x01\0\0\0\
\x04\0\0\0\x57\0\0\0\0\0\0\0\x01\0\0\0\x02\0\0\0\x73\0\0\0\0\0\0\0\x01\0\0\0\
\x03\0\0\0\x8f\0\0\0\0\0\0\0\x01\0\0\0\x04\0\0\0\x0c\x0e\x10\x0b\0\x2e\x64\x65\
\x62\x75\x67\x5f\x61\x62\x62\x72\x65\x76\0\x2e\x74\x65\x78\x74\0\x2e\x72\x65\
\x6c\x2e\x42\x54\x46\x2e\x65\x78\x74\0\x2e\x72\x65\x6c\x72\x61\x77\x5f\x74\x70\
\x2f\x73\x79\x73\x5f\x65\x78\x69\x74\0\x2e\x62\x73\x73\0\x2e\x72\x65\x6c\x2e\
\x64\x65\x62\x75\x67\x5f\x72\x61\x6e\x67\x65\x73\0\x2e\x64\x65\x62\x75\x67\x5f\
\x73\x74\x72\0\x2e\x72\x65\x6c\x72\x61\x77\x5f\x74\x70\x2f\x73\x79\x73\x5f\x65\
\x6e\x74\x65\x72\0\x2e\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\x69\x6e\x66\x6f\
\0\x2e\x6c\x6c\x76\x6d\x5f\x61\x64\x64\x72\x73\x69\x67\0\x5f\x6c\x69\x63\x65\
\x6e\x73\x65\0\x2e\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\x6c\x69\x6e\x65\0\
\x2e\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\x66\x72\x61\x6d\x65\0\x70\x72\x6f\
\x67\x33\x5f\x63\x61\x6c\x6c\x65\x64\0\x70\x72\x6f\x67\x32\x5f\x63\x61\x6c\x6c\
\x65\x64\0\x70\x72\x6f\x67\x31\x5f\x63\x61\x6c\x6c\x65\x64\0\x2e\x72\x65\x6c\
\x66\x65\x6e\x74\x72\x79\x2f\x75\x6e\x65\x78\x69\x73\x74\x69\x6e\x67\x2d\x6b\
\x70\x72\x6f\x62\x65\x2d\x77\x69\x6c\x6c\x2d\x66\x61\x69\x6c\x2d\x69\x66\x2d\
\x6c\x6f\x61\x64\x65\x64\0\x2e\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\x6c\x6f\
\x63\0\x74\x65\x73\x74\x5f\x61\x75\x74\x6f\x6c\x6f\x61\x64\x2e\x63\0\x2e\x73\
\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x2e\x72\x65\x6c\x2e\x42\
\x54\x46\0\x70\x72\x6f\x67\x33\0\x70\x72\x6f\x67\x32\0\x70\x72\x6f\x67\x31\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x2c\x01\0\0\x03\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x24\x11\0\0\0\0\0\0\x57\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0f\0\0\0\x01\0\0\0\x06\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x5c\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\x40\0\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x58\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa0\x0c\0\0\0\
\0\0\0\x10\0\0\0\0\0\0\0\x1c\0\0\0\x03\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\
\0\x26\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x70\0\0\0\0\0\0\0\x30\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x22\0\0\0\x09\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb0\x0c\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\
\x1c\0\0\0\x05\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xe0\0\0\0\x01\0\0\0\
\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdc\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\xc0\x0c\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x1c\0\0\0\x07\0\0\0\x08\
\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x36\0\0\0\x08\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\xe0\0\0\0\0\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x8c\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe0\0\0\
\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\x11\x01\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe4\0\0\0\0\0\0\0\x66\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x0d\x01\0\0\x09\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd0\x0c\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\
\x1c\0\0\0\x0b\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x01\0\0\0\x01\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x4a\x01\0\0\0\0\0\0\xe0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x71\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x2a\x02\0\0\0\0\0\0\x71\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x6d\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xf0\x0c\0\0\0\0\0\0\x40\x02\0\0\0\0\0\0\x1c\0\0\0\x0e\0\0\0\x08\0\0\0\0\0\0\0\
\x10\0\0\0\0\0\0\0\x3f\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x9b\x03\
\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x3b\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x30\x0f\0\0\0\0\0\0\x60\
\0\0\0\0\0\0\0\x1c\0\0\0\x10\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x4d\0\0\
\0\x01\0\0\0\x30\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xdb\x03\0\0\0\0\0\0\x71\x01\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\x40\x01\0\0\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x4c\x05\0\0\0\0\0\0\x83\x03\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x3c\x01\0\0\x09\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x90\x0f\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\x1c\0\0\0\x13\0\
\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x19\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\xcf\x08\0\0\0\0\0\0\x0c\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x15\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xd0\x0f\0\0\0\0\0\0\xc0\0\0\0\0\0\0\0\x1c\0\0\0\x15\0\0\0\x08\0\0\0\0\0\0\0\
\x10\0\0\0\0\0\0\0\xa8\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe0\x09\
\0\0\0\0\0\0\x58\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\xa4\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x90\x10\0\0\0\0\0\0\x60\
\0\0\0\0\0\0\0\x1c\0\0\0\x17\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x98\0\0\
\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x38\x0a\0\0\0\0\0\0\xb1\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x94\0\0\0\x09\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xf0\x10\0\0\0\0\0\0\x30\0\0\0\0\0\0\0\x1c\0\0\0\
\x19\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x7d\0\0\0\x03\x4c\xff\x6f\0\0\0\
\x80\0\0\0\0\0\0\0\0\0\0\0\0\x20\x11\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x1c\0\0\0\0\
\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x34\x01\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\xf0\x0a\0\0\0\0\0\0\xb0\x01\0\0\0\0\0\0\x01\0\0\0\x0b\0\0\0\
\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0";

	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return -1;
}

#endif /* __TEST_AUTOLOAD_SKEL_H__ */
