/* SPDX-License-Identifier: (LGPL-2.1 OR BSD-2-Clause) */

/* THIS FILE IS AUTOGENERATED! */
#ifndef __TEST_MMAP_SKEL_H__
#define __TEST_MMAP_SKEL_H__

#include <stdlib.h>
#include <bpf/libbpf.h>

struct test_mmap {
	struct bpf_object_skeleton *skeleton;
	struct bpf_object *obj;
	struct {
		struct bpf_map *data_map;
		struct bpf_map *rdonly_map;
		struct bpf_map *bss;
	} maps;
	struct {
		struct bpf_program *test_mmap;
	} progs;
	struct {
		struct bpf_link *test_mmap;
	} links;
	struct test_mmap__bss {
		__u64 in_val;
		__u64 out_val;
	} *bss;
};

static void
test_mmap__destroy(struct test_mmap *obj)
{
	if (!obj)
		return;
	if (obj->skeleton)
		bpf_object__destroy_skeleton(obj->skeleton);
	free(obj);
}

static inline int
test_mmap__create_skeleton(struct test_mmap *obj);

static inline struct test_mmap *
test_mmap__open_opts(const struct bpf_object_open_opts *opts)
{
	struct test_mmap *obj;

	obj = (struct test_mmap *)calloc(1, sizeof(*obj));
	if (!obj)
		return NULL;
	if (test_mmap__create_skeleton(obj))
		goto err;
	if (bpf_object__open_skeleton(obj->skeleton, opts))
		goto err;

	return obj;
err:
	test_mmap__destroy(obj);
	return NULL;
}

static inline struct test_mmap *
test_mmap__open(void)
{
	return test_mmap__open_opts(NULL);
}

static inline int
test_mmap__load(struct test_mmap *obj)
{
	return bpf_object__load_skeleton(obj->skeleton);
}

static inline struct test_mmap *
test_mmap__open_and_load(void)
{
	struct test_mmap *obj;

	obj = test_mmap__open();
	if (!obj)
		return NULL;
	if (test_mmap__load(obj)) {
		test_mmap__destroy(obj);
		return NULL;
	}
	return obj;
}

static inline int
test_mmap__attach(struct test_mmap *obj)
{
	return bpf_object__attach_skeleton(obj->skeleton);
}

static inline void
test_mmap__detach(struct test_mmap *obj)
{
	return bpf_object__detach_skeleton(obj->skeleton);
}

static inline int
test_mmap__create_skeleton(struct test_mmap *obj)
{
	struct bpf_object_skeleton *s;

	s = (struct bpf_object_skeleton *)calloc(1, sizeof(*s));
	if (!s)
		return -1;
	obj->skeleton = s;

	s->sz = sizeof(*s);
	s->name = "test_mmap";
	s->obj = &obj->obj;

	/* maps */
	s->map_cnt = 3;
	s->map_skel_sz = sizeof(*s->maps);
	s->maps = (struct bpf_map_skeleton *)calloc(s->map_cnt, s->map_skel_sz);
	if (!s->maps)
		goto err;

	s->maps[0].name = "data_map";
	s->maps[0].map = &obj->maps.data_map;

	s->maps[1].name = "rdonly_map";
	s->maps[1].map = &obj->maps.rdonly_map;

	s->maps[2].name = "test_mma.bss";
	s->maps[2].map = &obj->maps.bss;
	s->maps[2].mmaped = (void **)&obj->bss;

	/* programs */
	s->prog_cnt = 1;
	s->prog_skel_sz = sizeof(*s->progs);
	s->progs = (struct bpf_prog_skeleton *)calloc(s->prog_cnt, s->prog_skel_sz);
	if (!s->progs)
		goto err;

	s->progs[0].name = "test_mmap";
	s->progs[0].prog = &obj->progs.test_mmap;
	s->progs[0].link = &obj->links.test_mmap;

	s->data_sz = 7872;
	s->data = (void *)"\
\x7f\x45\x4c\x46\x02\x01\x01\0\0\0\0\0\0\0\0\0\x01\0\xf7\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x19\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\x40\0\x17\0\x01\
\0\x18\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x79\x61\0\0\0\0\0\0\x18\x02\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\x7b\x12\0\0\0\0\0\0\xb4\x01\0\0\0\0\0\0\x63\x1a\xfc\xff\0\0\0\
\0\xb4\x01\0\0\x01\0\0\0\x63\x1a\xf8\xff\0\0\0\0\xb4\x01\0\0\x02\0\0\0\x63\x1a\
\xf4\xff\0\0\0\0\xb4\x01\0\0\xdc\x05\0\0\x63\x1a\xf0\xff\0\0\0\0\xbf\xa2\0\0\0\
\0\0\0\x07\x02\0\0\xf4\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x18\x03\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\0\xbf\xa2\0\
\0\0\0\0\0\x07\x02\0\0\xfc\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x85\
\0\0\0\x01\0\0\0\x15\0\x0b\0\0\0\0\0\x79\x01\0\0\0\0\0\0\x67\x01\0\0\x01\0\0\0\
\x7b\x1a\xe8\xff\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\xf8\xff\xff\xff\xbf\
\xa3\0\0\0\0\0\0\x07\x03\0\0\xe8\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\0\x79\x61\0\0\0\0\0\0\x27\x01\0\0\x03\
\0\0\0\x7b\x1a\xe8\xff\0\0\0\0\xbf\xa2\0\0\0\0\0\0\x07\x02\0\0\xf0\xff\xff\xff\
\xbf\xa3\0\0\0\0\0\0\x07\x03\0\0\xe8\xff\xff\xff\x18\x01\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\xb7\x04\0\0\0\0\0\0\x85\0\0\0\x02\0\0\0\xb4\0\0\0\0\0\0\0\x95\0\0\0\0\0\
\0\0\x47\x50\x4c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x38\0\0\0\0\0\0\0\xb0\0\0\0\0\0\0\0\x03\0\x11\0\
\x9f\xb0\0\0\0\0\0\0\0\xa0\x01\0\0\0\0\0\0\x02\0\x7a\x14\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x48\0\0\0\0\0\0\0\xf8\0\0\0\0\0\0\0\x03\0\x11\x01\x9f\xf8\0\0\0\0\0\
\0\0\x38\x01\0\0\0\0\0\0\x02\0\x7a\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x58\0\0\
\0\0\0\0\0\x70\0\0\0\0\0\0\0\x03\0\x11\x02\x9f\x70\0\0\0\0\0\0\0\xa0\x01\0\0\0\
\0\0\0\x02\0\x7a\x0c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x68\0\0\0\0\0\0\0\x50\x01\
\0\0\0\0\0\0\x04\0\x11\xdc\x0b\x9f\x50\x01\0\0\0\0\0\0\xa0\x01\0\0\0\0\0\0\x02\
\0\x7a\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd8\0\0\0\0\0\0\0\x38\x01\0\0\0\0\0\
\0\x01\0\x50\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xf0\0\0\0\0\0\0\0\xf8\0\0\0\0\0\0\
\0\x01\0\x51\xf8\0\0\0\0\0\0\0\x38\x01\0\0\0\0\0\0\x02\0\x7a\0\x48\x01\0\0\0\0\
\0\0\x50\x01\0\0\0\0\0\0\x01\0\x51\x50\x01\0\0\0\0\0\0\xa0\x01\0\0\0\0\0\0\x02\
\0\x7a\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\x11\x01\x25\x0e\x13\x05\x03\x0e\
\x10\x17\x1b\x0e\x11\x01\x12\x06\0\0\x02\x34\0\x03\x0e\x49\x13\x3f\x19\x3a\x0b\
\x3b\x0b\x02\x18\0\0\x03\x01\x01\x49\x13\0\0\x04\x21\0\x49\x13\x37\x0b\0\0\x05\
\x24\0\x03\x0e\x3e\x0b\x0b\x0b\0\0\x06\x24\0\x03\x0e\x0b\x0b\x3e\x0b\0\0\x07\
\x16\0\x49\x13\x03\x0e\x3a\x0b\x3b\x0b\0\0\x08\x13\x01\x0b\x0b\x3a\x0b\x3b\x0b\
\0\0\x09\x0d\0\x03\x0e\x49\x13\x3a\x0b\x3b\x0b\x38\x0b\0\0\x0a\x0f\0\x49\x13\0\
\0\x0b\x21\0\x49\x13\x37\x05\0\0\x0c\x34\0\x03\x0e\x49\x13\x3a\x0b\x3b\x0b\0\0\
\x0d\x15\x01\x49\x13\x27\x19\0\0\x0e\x05\0\x49\x13\0\0\x0f\x0f\0\0\0\x10\x26\0\
\0\0\x11\x2e\x01\x11\x01\x12\x06\x40\x18\x97\x42\x19\x03\x0e\x3a\x0b\x3b\x0b\
\x27\x19\x49\x13\x3f\x19\0\0\x12\x05\0\x03\x0e\x3a\x0b\x3b\x0b\x49\x13\0\0\x13\
\x34\0\x02\x17\x03\x0e\x3a\x0b\x3b\x0b\x49\x13\0\0\0\x96\x02\0\0\x04\0\0\0\0\0\
\x08\x01\0\0\0\0\x0c\0\x44\0\0\0\0\0\0\0\x56\0\0\0\0\0\0\0\0\0\0\0\xa0\x01\0\0\
\x02\xc6\0\0\0\x3f\0\0\0\x01\x08\x09\x03\0\0\0\0\0\0\0\0\x03\x4b\0\0\0\x04\x52\
\0\0\0\x04\0\x05\xcf\0\0\0\x06\x01\x06\xd4\0\0\0\x08\x07\x02\xe8\0\0\0\x6e\0\0\
\0\x01\x1a\x09\x03\0\0\0\0\0\0\0\0\x07\x79\0\0\0\x06\x01\0\0\x02\x1f\x05\xef\0\
\0\0\x07\x08\x02\x0c\x01\0\0\x6e\0\0\0\x01\x1b\x09\x03\0\0\0\0\0\0\0\0\x02\x14\
\x01\0\0\xaa\0\0\0\x01\x10\x09\x03\0\0\0\0\0\0\0\0\x08\x28\x01\x0a\x09\x1f\x01\
\0\0\xeb\0\0\0\x01\x0b\0\x09\x28\x01\0\0\x03\x01\0\0\x01\x0c\x08\x09\x34\x01\0\
\0\x15\x01\0\0\x01\x0d\x10\x09\x3e\x01\0\0\x27\x01\0\0\x01\x0e\x18\x09\x55\x01\
\0\0\x3e\x01\0\0\x01\x0f\x20\0\x0a\xf0\0\0\0\x03\xfc\0\0\0\x04\x52\0\0\0\x02\0\
\x05\x24\x01\0\0\x05\x04\x0a\x08\x01\0\0\x03\xfc\0\0\0\x0b\x52\0\0\0\0\x10\0\
\x0a\x1a\x01\0\0\x03\xfc\0\0\0\x0b\x52\0\0\0\x80\x04\0\x0a\x2c\x01\0\0\x07\x37\
\x01\0\0\x4f\x01\0\0\x02\x1b\x05\x42\x01\0\0\x07\x04\x0a\x4b\0\0\0\x02\x5b\x01\
\0\0\x58\x01\0\0\x01\x18\x09\x03\0\0\0\0\0\0\0\0\x08\x28\x01\x12\x09\x1f\x01\0\
\0\xeb\0\0\0\x01\x13\0\x09\x28\x01\0\0\x99\x01\0\0\x01\x14\x08\x09\x34\x01\0\0\
\xab\x01\0\0\x01\x15\x10\x09\x3e\x01\0\0\x27\x01\0\0\x01\x16\x18\x09\x55\x01\0\
\0\xbd\x01\0\0\x01\x17\x20\0\x0a\x9e\x01\0\0\x03\xfc\0\0\0\x0b\x52\0\0\0\0\x08\
\0\x0a\xb0\x01\0\0\x03\xfc\0\0\0\x0b\x52\0\0\0\0\x04\0\x0a\x6e\0\0\0\x0c\x64\
\x01\0\0\xcd\x01\0\0\x03\x47\x0a\xd2\x01\0\0\x0d\xec\x01\0\0\x0e\xf3\x01\0\0\
\x0e\xf4\x01\0\0\x0e\xf4\x01\0\0\x0e\x6e\0\0\0\0\x05\x78\x01\0\0\x05\x08\x0f\
\x0a\xf9\x01\0\0\x10\x0c\x81\x01\0\0\x05\x02\0\0\x03\x31\x0a\x0a\x02\0\0\x0d\
\xf3\x01\0\0\x0e\xf3\x01\0\0\x0e\xf4\x01\0\0\0\x11\0\0\0\0\0\0\0\0\xa0\x01\0\0\
\x01\x5a\x95\x01\0\0\x01\x1e\xfc\0\0\0\x12\x9f\x01\0\0\x01\x1e\xf3\x01\0\0\x13\
\0\0\0\0\xa3\x01\0\0\x01\x20\xfc\0\0\0\x13\x39\0\0\0\xa8\x01\0\0\x01\x20\xfc\0\
\0\0\x13\x72\0\0\0\xac\x01\0\0\x01\x20\xfc\0\0\0\x13\xab\0\0\0\xb0\x01\0\0\x01\
\x20\xfc\0\0\0\x13\xe5\0\0\0\xb4\x01\0\0\x01\x21\xbd\x01\0\0\x13\x08\x01\0\0\
\xb6\x01\0\0\x01\x21\x6e\0\0\0\0\0\x63\x6c\x61\x6e\x67\x20\x76\x65\x72\x73\x69\
\x6f\x6e\x20\x31\x32\x2e\x30\x2e\x31\x20\x28\x52\x65\x64\x20\x48\x61\x74\x20\
\x31\x32\x2e\x30\x2e\x31\x2d\x32\x2e\x6d\x6f\x64\x75\x6c\x65\x5f\x65\x6c\x38\
\x2e\x35\x2e\x30\x2b\x39\x37\x35\x2b\x35\x65\x35\x32\x66\x39\x39\x34\x29\0\x70\
\x72\x6f\x67\x73\x2f\x74\x65\x73\x74\x5f\x6d\x6d\x61\x70\x2e\x63\0\x2f\x62\x75\
\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\
\x6b\x65\x72\x6e\x65\x6c\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x33\x34\x38\x2e\x37\
\x2e\x31\x2e\x65\x6c\x38\x5f\x35\x2f\x6c\x69\x6e\x75\x78\x2d\x34\x2e\x31\x38\
\x2e\x30\x2d\x33\x34\x38\x2e\x37\x2e\x31\x2e\x65\x6c\x38\x5f\x35\x2e\x78\x38\
\x36\x5f\x36\x34\x2f\x74\x6f\x6f\x6c\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\
\x73\x65\x6c\x66\x74\x65\x73\x74\x73\x2f\x62\x70\x66\0\x5f\x6c\x69\x63\x65\x6e\
\x73\x65\0\x63\x68\x61\x72\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\
\x5f\x54\x59\x50\x45\x5f\x5f\0\x69\x6e\x5f\x76\x61\x6c\0\x6c\x6f\x6e\x67\x20\
\x6c\x6f\x6e\x67\x20\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x5f\x5f\
\x75\x36\x34\0\x6f\x75\x74\x5f\x76\x61\x6c\0\x72\x64\x6f\x6e\x6c\x79\x5f\x6d\
\x61\x70\0\x74\x79\x70\x65\0\x69\x6e\x74\0\x6d\x61\x78\x5f\x65\x6e\x74\x72\x69\
\x65\x73\0\x6d\x61\x70\x5f\x66\x6c\x61\x67\x73\0\x6b\x65\x79\0\x75\x6e\x73\x69\
\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x5f\x5f\x75\x33\x32\0\x76\x61\x6c\x75\x65\0\
\x64\x61\x74\x61\x5f\x6d\x61\x70\0\x62\x70\x66\x5f\x6d\x61\x70\x5f\x75\x70\x64\
\x61\x74\x65\x5f\x65\x6c\x65\x6d\0\x6c\x6f\x6e\x67\x20\x69\x6e\x74\0\x62\x70\
\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\x6d\0\x74\x65\
\x73\x74\x5f\x6d\x6d\x61\x70\0\x63\x74\x78\0\x7a\x65\x72\x6f\0\x6f\x6e\x65\0\
\x74\x77\x6f\0\x66\x61\x72\0\x70\0\x76\x61\x6c\0\x9f\xeb\x01\0\x18\0\0\0\0\0\0\
\0\xc4\x02\0\0\xc4\x02\0\0\xa3\x02\0\0\0\0\0\0\0\0\0\x02\x03\0\0\0\x01\0\0\0\0\
\0\0\x01\x04\0\0\0\x20\0\0\x01\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\
\x02\0\0\0\x05\0\0\0\0\0\0\x01\x04\0\0\0\x20\0\0\0\0\0\0\0\0\0\0\x02\x06\0\0\0\
\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\x02\x08\
\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\x04\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\
\x02\x0a\0\0\0\x19\0\0\0\0\0\0\x08\x0b\0\0\0\x1f\0\0\0\0\0\0\x01\x04\0\0\0\x20\
\0\0\0\0\0\0\0\0\0\0\x02\x0d\0\0\0\x2c\0\0\0\0\0\0\x08\x0e\0\0\0\x32\0\0\0\0\0\
\0\x01\x08\0\0\0\x40\0\0\0\0\0\0\0\x05\0\0\x04\x28\0\0\0\x49\0\0\0\x01\0\0\0\0\
\0\0\0\x4e\0\0\0\x05\0\0\0\x40\0\0\0\x5a\0\0\0\x07\0\0\0\x80\0\0\0\x64\0\0\0\
\x09\0\0\0\xc0\0\0\0\x68\0\0\0\x0c\0\0\0\0\x01\0\0\x6e\0\0\0\0\0\0\x0e\x0f\0\0\
\0\x01\0\0\0\0\0\0\0\0\0\0\x02\x12\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\0\0\0\
\x04\0\0\0\0\x10\0\0\0\0\0\0\0\0\0\x02\x14\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x02\
\0\0\0\x04\0\0\0\x80\x04\0\0\0\0\0\0\0\0\0\x02\x16\0\0\0\x77\0\0\0\0\0\0\x01\
\x01\0\0\0\x08\0\0\x01\0\0\0\0\x05\0\0\x04\x28\0\0\0\x49\0\0\0\x01\0\0\0\0\0\0\
\0\x4e\0\0\0\x11\0\0\0\x40\0\0\0\x5a\0\0\0\x13\0\0\0\x80\0\0\0\x64\0\0\0\x09\0\
\0\0\xc0\0\0\0\x68\0\0\0\x15\0\0\0\0\x01\0\0\x7c\0\0\0\0\0\0\x0e\x17\0\0\0\x01\
\0\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0\x01\0\0\x0d\x02\0\0\0\x87\0\0\0\x19\0\
\0\0\x8b\0\0\0\x01\0\0\x0c\x1a\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\0\x16\0\0\0\x04\0\
\0\0\x04\0\0\0\x78\x02\0\0\0\0\0\x0e\x1c\0\0\0\x01\0\0\0\x81\x02\0\0\0\0\0\x0e\
\x0d\0\0\0\x01\0\0\0\x88\x02\0\0\0\0\0\x0e\x0d\0\0\0\x01\0\0\0\x90\x02\0\0\x02\
\0\0\x0f\0\0\0\0\x1e\0\0\0\0\0\0\0\x08\0\0\0\x1f\0\0\0\0\0\0\0\x08\0\0\0\x95\
\x02\0\0\x02\0\0\x0f\0\0\0\0\x10\0\0\0\0\0\0\0\x28\0\0\0\x18\0\0\0\0\0\0\0\x28\
\0\0\0\x9b\x02\0\0\x01\0\0\x0f\0\0\0\0\x1d\0\0\0\0\0\0\0\x04\0\0\0\0\x69\x6e\
\x74\0\x5f\x5f\x41\x52\x52\x41\x59\x5f\x53\x49\x5a\x45\x5f\x54\x59\x50\x45\x5f\
\x5f\0\x5f\x5f\x75\x33\x32\0\x75\x6e\x73\x69\x67\x6e\x65\x64\x20\x69\x6e\x74\0\
\x5f\x5f\x75\x36\x34\0\x6c\x6f\x6e\x67\x20\x6c\x6f\x6e\x67\x20\x75\x6e\x73\x69\
\x67\x6e\x65\x64\x20\x69\x6e\x74\0\x74\x79\x70\x65\0\x6d\x61\x78\x5f\x65\x6e\
\x74\x72\x69\x65\x73\0\x6d\x61\x70\x5f\x66\x6c\x61\x67\x73\0\x6b\x65\x79\0\x76\
\x61\x6c\x75\x65\0\x64\x61\x74\x61\x5f\x6d\x61\x70\0\x63\x68\x61\x72\0\x72\x64\
\x6f\x6e\x6c\x79\x5f\x6d\x61\x70\0\x63\x74\x78\0\x74\x65\x73\x74\x5f\x6d\x6d\
\x61\x70\0\x72\x61\x77\x5f\x74\x72\x61\x63\x65\x70\x6f\x69\x6e\x74\x2f\x73\x79\
\x73\x5f\x65\x6e\x74\x65\x72\0\x2f\x62\x75\x69\x6c\x64\x64\x69\x72\x2f\x62\x75\
\x69\x6c\x64\x2f\x42\x55\x49\x4c\x44\x2f\x6b\x65\x72\x6e\x65\x6c\x2d\x34\x2e\
\x31\x38\x2e\x30\x2d\x33\x34\x38\x2e\x37\x2e\x31\x2e\x65\x6c\x38\x5f\x35\x2f\
\x6c\x69\x6e\x75\x78\x2d\x34\x2e\x31\x38\x2e\x30\x2d\x33\x34\x38\x2e\x37\x2e\
\x31\x2e\x65\x6c\x38\x5f\x35\x2e\x78\x38\x36\x5f\x36\x34\x2f\x74\x6f\x6f\x6c\
\x73\x2f\x74\x65\x73\x74\x69\x6e\x67\x2f\x73\x65\x6c\x66\x74\x65\x73\x74\x73\
\x2f\x62\x70\x66\x2f\x70\x72\x6f\x67\x73\x2f\x74\x65\x73\x74\x5f\x6d\x6d\x61\
\x70\x2e\x63\0\x09\x6f\x75\x74\x5f\x76\x61\x6c\x20\x3d\x20\x69\x6e\x5f\x76\x61\
\x6c\x3b\0\x09\x69\x6e\x74\x20\x7a\x65\x72\x6f\x20\x3d\x20\x30\x2c\x20\x6f\x6e\
\x65\x20\x3d\x20\x31\x2c\x20\x74\x77\x6f\x20\x3d\x20\x32\x2c\x20\x66\x61\x72\
\x20\x3d\x20\x31\x35\x30\x30\x3b\0\x09\x62\x70\x66\x5f\x6d\x61\x70\x5f\x75\x70\
\x64\x61\x74\x65\x5f\x65\x6c\x65\x6d\x28\x26\x64\x61\x74\x61\x5f\x6d\x61\x70\
\x2c\x20\x26\x74\x77\x6f\x2c\x20\x28\x63\x6f\x6e\x73\x74\x20\x76\x6f\x69\x64\
\x20\x2a\x29\x26\x69\x6e\x5f\x76\x61\x6c\x2c\x20\x30\x29\x3b\0\x09\x70\x20\x3d\
\x20\x62\x70\x66\x5f\x6d\x61\x70\x5f\x6c\x6f\x6f\x6b\x75\x70\x5f\x65\x6c\x65\
\x6d\x28\x26\x64\x61\x74\x61\x5f\x6d\x61\x70\x2c\x20\x26\x7a\x65\x72\x6f\x29\
\x3b\0\x09\x69\x66\x20\x28\x70\x29\x20\x7b\0\x09\x09\x76\x61\x6c\x20\x3d\x20\
\x28\x2a\x70\x29\x20\x2a\x20\x32\x3b\0\x09\x09\x62\x70\x66\x5f\x6d\x61\x70\x5f\
\x75\x70\x64\x61\x74\x65\x5f\x65\x6c\x65\x6d\x28\x26\x64\x61\x74\x61\x5f\x6d\
\x61\x70\x2c\x20\x26\x6f\x6e\x65\x2c\x20\x26\x76\x61\x6c\x2c\x20\x30\x29\x3b\0\
\x09\x76\x61\x6c\x20\x3d\x20\x69\x6e\x5f\x76\x61\x6c\x20\x2a\x20\x33\x3b\0\x09\
\x62\x70\x66\x5f\x6d\x61\x70\x5f\x75\x70\x64\x61\x74\x65\x5f\x65\x6c\x65\x6d\
\x28\x26\x64\x61\x74\x61\x5f\x6d\x61\x70\x2c\x20\x26\x66\x61\x72\x2c\x20\x26\
\x76\x61\x6c\x2c\x20\x30\x29\x3b\0\x09\x72\x65\x74\x75\x72\x6e\x20\x30\x3b\0\
\x5f\x6c\x69\x63\x65\x6e\x73\x65\0\x69\x6e\x5f\x76\x61\x6c\0\x6f\x75\x74\x5f\
\x76\x61\x6c\0\x2e\x62\x73\x73\0\x2e\x6d\x61\x70\x73\0\x6c\x69\x63\x65\x6e\x73\
\x65\0\x9f\xeb\x01\0\x20\0\0\0\0\0\0\0\x14\0\0\0\x14\0\0\0\x6c\x01\0\0\x80\x01\
\0\0\0\0\0\0\x08\0\0\0\x95\0\0\0\x01\0\0\0\0\0\0\0\x1b\0\0\0\x10\0\0\0\x95\0\0\
\0\x16\0\0\0\0\0\0\0\xae\0\0\0\x30\x01\0\0\x0c\x8c\0\0\x18\0\0\0\xae\0\0\0\x30\
\x01\0\0\x0a\x8c\0\0\x38\0\0\0\xae\0\0\0\x43\x01\0\0\x06\x80\0\0\x48\0\0\0\xae\
\0\0\0\x43\x01\0\0\x10\x80\0\0\x58\0\0\0\xae\0\0\0\x43\x01\0\0\x19\x80\0\0\x68\
\0\0\0\xae\0\0\0\x43\x01\0\0\x22\x80\0\0\x78\0\0\0\xae\0\0\0\0\0\0\0\0\0\0\0\
\x80\0\0\0\xae\0\0\0\x70\x01\0\0\x02\x98\0\0\xb8\0\0\0\xae\0\0\0\0\0\0\0\0\0\0\
\0\xc0\0\0\0\xae\0\0\0\xb1\x01\0\0\x06\xa4\0\0\xd8\0\0\0\xae\0\0\0\xdd\x01\0\0\
\x06\xa8\0\0\xe0\0\0\0\xae\0\0\0\xe7\x01\0\0\x0a\xac\0\0\xe8\0\0\0\xae\0\0\0\
\xe7\x01\0\0\x0e\xac\0\0\xf0\0\0\0\xae\0\0\0\xe7\x01\0\0\x07\xac\0\0\0\x01\0\0\
\xae\0\0\0\0\0\0\0\0\0\0\0\x18\x01\0\0\xae\0\0\0\xf9\x01\0\0\x03\xb0\0\0\x38\
\x01\0\0\xae\0\0\0\x2a\x02\0\0\x08\xc0\0\0\x40\x01\0\0\xae\0\0\0\x2a\x02\0\0\
\x0f\xc0\0\0\x48\x01\0\0\xae\0\0\0\x2a\x02\0\0\x06\xc0\0\0\x58\x01\0\0\xae\0\0\
\0\x2a\x02\0\0\x08\xc0\0\0\x70\x01\0\0\xae\0\0\0\x3d\x02\0\0\x02\xc4\0\0\x90\
\x01\0\0\xae\0\0\0\x6d\x02\0\0\x02\xcc\0\0\x0c\0\0\0\xff\xff\xff\xff\x04\0\x08\
\0\x08\x7c\x0b\0\x14\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xa0\x01\0\0\0\0\0\0\xe4\0\0\
\0\x04\0\x77\0\0\0\x08\x01\x01\xfb\x0e\x0d\0\x01\x01\x01\x01\0\0\0\x01\0\0\x01\
\x70\x72\x6f\x67\x73\0\x2f\x75\x73\x72\x2f\x69\x6e\x63\x6c\x75\x64\x65\x2f\x61\
\x73\x6d\x2d\x67\x65\x6e\x65\x72\x69\x63\0\x74\x6f\x6f\x6c\x73\x2f\x69\x6e\x63\
\x6c\x75\x64\x65\x2f\x62\x70\x66\0\0\x74\x65\x73\x74\x5f\x6d\x6d\x61\x70\x2e\
\x63\0\x01\0\0\x69\x6e\x74\x2d\x6c\x6c\x36\x34\x2e\x68\0\x02\0\0\x62\x70\x66\
\x5f\x68\x65\x6c\x70\x65\x72\x5f\x64\x65\x66\x73\x2e\x68\0\x03\0\0\0\0\x09\x02\
\0\0\0\0\0\0\0\0\x03\x1e\x01\x05\x0c\x0a\x16\x05\x0a\x06\x3c\x05\x06\x06\x47\
\x05\x10\x06\x2e\x05\x19\x2e\x05\x22\x2e\x03\x60\x20\x05\x02\x06\x03\x26\x2e\
\x06\x03\x5a\x66\x05\x06\x06\x03\x29\x2e\x3d\x05\x0a\x21\x05\x0e\x06\x20\x05\
\x07\x20\x03\x55\x20\x05\x03\x06\x03\x2c\x4a\x05\x08\x4e\x05\x0f\x06\x20\x05\
\x06\x20\x03\x50\x20\x05\x08\x03\x30\x20\x05\x02\x06\x3d\x4c\x02\x02\0\x01\x01\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xd5\0\0\0\x04\0\xf1\xff\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\xfa\0\0\0\0\0\x03\0\x38\x01\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x03\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x08\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x03\0\x0c\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x11\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x03\0\x13\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\xa0\0\0\0\x11\0\x05\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\x6a\0\0\0\x11\0\
\x07\0\0\0\0\0\0\0\0\0\x28\0\0\0\0\0\0\0\x8b\0\0\0\x11\0\x06\0\0\0\0\0\0\0\0\0\
\x08\0\0\0\0\0\0\0\x83\0\0\0\x11\0\x06\0\x08\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\
\x5f\0\0\0\x11\0\x07\0\x28\0\0\0\0\0\0\0\x28\0\0\0\0\0\0\0\x55\0\0\0\x12\0\x03\
\0\0\0\0\0\0\0\0\0\xa0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\x0b\0\0\0\x18\
\0\0\0\0\0\0\0\x01\0\0\0\x0c\0\0\0\x80\0\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\x90\0\
\0\0\0\0\0\0\x01\0\0\0\x0b\0\0\0\xc0\0\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\x18\x01\
\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\x70\x01\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\x06\0\
\0\0\0\0\0\0\x0a\0\0\0\x05\0\0\0\x0c\0\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x12\0\0\
\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x16\0\0\0\0\0\0\0\x0a\0\0\0\x08\0\0\0\x1a\0\0\0\
\0\0\0\0\x0a\0\0\0\x06\0\0\0\x1e\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\x2b\0\0\0\0\
\0\0\0\x0a\0\0\0\x06\0\0\0\x37\0\0\0\0\0\0\0\x01\0\0\0\x09\0\0\0\x4c\0\0\0\0\0\
\0\0\x0a\0\0\0\x06\0\0\0\x53\0\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x5a\0\0\0\0\0\0\
\0\x0a\0\0\0\x06\0\0\0\x66\0\0\0\0\0\0\0\x01\0\0\0\x0b\0\0\0\x73\0\0\0\0\0\0\0\
\x0a\0\0\0\x06\0\0\0\x7a\0\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x81\0\0\0\0\0\0\0\
\x0a\0\0\0\x06\0\0\0\x8d\0\0\0\0\0\0\0\x01\0\0\0\x0c\0\0\0\x96\0\0\0\0\0\0\0\
\x0a\0\0\0\x06\0\0\0\xa2\0\0\0\0\0\0\0\x01\0\0\0\x0d\0\0\0\xaf\0\0\0\0\0\0\0\
\x0a\0\0\0\x06\0\0\0\xbb\0\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\xc7\0\0\0\0\0\0\0\
\x0a\0\0\0\x06\0\0\0\xd3\0\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\xdf\0\0\0\0\0\0\0\
\x0a\0\0\0\x06\0\0\0\xfd\0\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x31\x01\0\0\0\0\0\0\
\x0a\0\0\0\x06\0\0\0\x38\x01\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x44\x01\0\0\0\0\0\
\0\x0a\0\0\0\x06\0\0\0\x50\x01\0\0\0\0\0\0\x01\0\0\0\x0a\0\0\0\x5d\x01\0\0\0\0\
\0\0\x0a\0\0\0\x06\0\0\0\x69\x01\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x75\x01\0\0\0\
\0\0\0\x0a\0\0\0\x06\0\0\0\x81\x01\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x8d\x01\0\0\
\0\0\0\0\x0a\0\0\0\x06\0\0\0\xc3\x01\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\xed\x01\0\
\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\xfb\x01\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x1b\x02\
\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\x29\x02\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x34\
\x02\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x3f\x02\0\0\0\0\0\0\x0a\0\0\0\x04\0\0\0\
\x43\x02\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x4e\x02\0\0\0\0\0\0\x0a\0\0\0\x04\0\0\
\0\x52\x02\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x5d\x02\0\0\0\0\0\0\x0a\0\0\0\x04\0\
\0\0\x61\x02\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x6c\x02\0\0\0\0\0\0\x0a\0\0\0\x04\
\0\0\0\x70\x02\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x7b\x02\0\0\0\0\0\0\x0a\0\0\0\
\x04\0\0\0\x7f\x02\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x8a\x02\0\0\0\0\0\0\x0a\0\0\
\0\x04\0\0\0\x8e\x02\0\0\0\0\0\0\x0a\0\0\0\x06\0\0\0\x8c\x02\0\0\0\0\0\0\0\0\0\
\0\x0b\0\0\0\x98\x02\0\0\0\0\0\0\0\0\0\0\x0c\0\0\0\xb0\x02\0\0\0\0\0\0\0\0\0\0\
\x0a\0\0\0\xbc\x02\0\0\0\0\0\0\0\0\0\0\x0d\0\0\0\xd4\x02\0\0\0\0\0\0\0\0\0\0\
\x09\0\0\0\x2c\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x40\0\0\0\0\0\0\0\0\0\0\0\x03\0\
\0\0\x50\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x60\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\
\x70\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x90\0\
\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\xa0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\xb0\0\0\0\0\
\0\0\0\0\0\0\0\x03\0\0\0\xc0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\xd0\0\0\0\0\0\0\0\
\0\0\0\0\x03\0\0\0\xe0\0\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\xf0\0\0\0\0\0\0\0\0\0\0\
\0\x03\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x10\x01\0\0\0\0\0\0\0\0\0\0\
\x03\0\0\0\x20\x01\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x30\x01\0\0\0\0\0\0\0\0\0\0\
\x03\0\0\0\x40\x01\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x50\x01\0\0\0\0\0\0\0\0\0\0\
\x03\0\0\0\x60\x01\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x70\x01\0\0\0\0\0\0\0\0\0\0\
\x03\0\0\0\x80\x01\0\0\0\0\0\0\0\0\0\0\x03\0\0\0\x90\x01\0\0\0\0\0\0\0\0\0\0\
\x03\0\0\0\x14\0\0\0\0\0\0\0\x0a\0\0\0\x07\0\0\0\x18\0\0\0\0\0\0\0\x01\0\0\0\
\x03\0\0\0\x84\0\0\0\0\0\0\0\x01\0\0\0\x03\0\0\0\x0e\x09\x0b\x0a\x0d\0\x2e\x64\
\x65\x62\x75\x67\x5f\x61\x62\x62\x72\x65\x76\0\x2e\x74\x65\x78\x74\0\x2e\x72\
\x65\x6c\x2e\x42\x54\x46\x2e\x65\x78\x74\0\x2e\x62\x73\x73\0\x2e\x6d\x61\x70\
\x73\0\x2e\x64\x65\x62\x75\x67\x5f\x73\x74\x72\0\x2e\x72\x65\x6c\x72\x61\x77\
\x5f\x74\x72\x61\x63\x65\x70\x6f\x69\x6e\x74\x2f\x73\x79\x73\x5f\x65\x6e\x74\
\x65\x72\0\x74\x65\x73\x74\x5f\x6d\x6d\x61\x70\0\x72\x64\x6f\x6e\x6c\x79\x5f\
\x6d\x61\x70\0\x64\x61\x74\x61\x5f\x6d\x61\x70\0\x2e\x72\x65\x6c\x2e\x64\x65\
\x62\x75\x67\x5f\x69\x6e\x66\x6f\0\x6f\x75\x74\x5f\x76\x61\x6c\0\x69\x6e\x5f\
\x76\x61\x6c\0\x2e\x6c\x6c\x76\x6d\x5f\x61\x64\x64\x72\x73\x69\x67\0\x5f\x6c\
\x69\x63\x65\x6e\x73\x65\0\x2e\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\x6c\x69\
\x6e\x65\0\x2e\x72\x65\x6c\x2e\x64\x65\x62\x75\x67\x5f\x66\x72\x61\x6d\x65\0\
\x2e\x64\x65\x62\x75\x67\x5f\x6c\x6f\x63\0\x74\x65\x73\x74\x5f\x6d\x6d\x61\x70\
\x2e\x63\0\x2e\x73\x74\x72\x74\x61\x62\0\x2e\x73\x79\x6d\x74\x61\x62\0\x2e\x72\
\x65\x6c\x2e\x42\x54\x46\0\x4c\x42\x42\x30\x5f\x32\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe1\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\xfd\x17\0\0\0\0\0\0\x01\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\x0f\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x3c\
\0\0\0\x01\0\0\0\x06\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x40\0\0\0\0\0\0\0\xa0\x01\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x38\0\0\0\x09\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x68\x12\0\0\0\0\0\0\x70\0\0\0\0\0\0\0\x16\0\
\0\0\x03\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xa1\0\0\0\x01\0\0\0\x03\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\xe0\x01\0\0\0\0\0\0\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x22\0\0\0\x08\0\0\0\x03\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\xe8\x01\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\x27\0\0\0\x01\0\0\0\x03\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xe8\x01\0\0\0\0\0\0\x50\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\xca\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x38\x02\0\0\0\0\
\0\0\x66\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\
\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x9e\x03\0\0\0\0\0\0\xdf\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x77\0\0\0\x01\0\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x7d\x04\0\0\0\0\0\0\x9a\x02\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x73\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\xd8\x12\0\0\0\0\0\0\x30\x03\0\0\0\0\0\0\x16\0\0\0\x0a\0\0\0\
\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x2d\0\0\0\x01\0\0\0\x30\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\x17\x07\0\0\0\0\0\0\xba\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\
\0\0\0\0\x01\0\0\0\0\0\0\0\xf5\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\xd1\x08\0\0\0\0\0\0\x7f\x05\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\xf1\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x08\x16\0\0\0\
\0\0\0\x50\0\0\0\0\0\0\0\x16\0\0\0\x0d\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\
\0\x19\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x50\x0e\0\0\0\0\0\0\xa0\
\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x15\0\0\0\
\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x58\x16\0\0\0\0\0\0\x70\x01\0\0\0\0\
\0\0\x16\0\0\0\x0f\0\0\0\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xbd\0\0\0\x01\0\0\
\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xf0\x0f\0\0\0\0\0\0\x28\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x08\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb9\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\xc8\x17\0\0\0\0\0\0\x20\0\0\0\0\0\0\0\x16\0\0\0\x11\0\0\0\
\x08\0\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\xad\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\0\x18\x10\0\0\0\0\0\0\xe8\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\0\0\0\0\0\
\0\0\0\0\0\0\0\0\0\0\xa9\0\0\0\x09\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xe8\
\x17\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\x16\0\0\0\x13\0\0\0\x08\0\0\0\0\0\0\0\x10\0\
\0\0\0\0\0\0\x92\0\0\0\x03\x4c\xff\x6f\0\0\0\x80\0\0\0\0\0\0\0\0\0\0\0\0\xf8\
\x17\0\0\0\0\0\0\x05\0\0\0\0\0\0\0\x16\0\0\0\0\0\0\0\x01\0\0\0\0\0\0\0\0\0\0\0\
\0\0\0\0\xe9\0\0\0\x02\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x11\0\0\0\0\0\0\
\x68\x01\0\0\0\0\0\0\x01\0\0\0\x09\0\0\0\x08\0\0\0\0\0\0\0\x18\0\0\0\0\0\0\0";

	return 0;
err:
	bpf_object__destroy_skeleton(s);
	return -1;
}

#endif /* __TEST_MMAP_SKEL_H__ */
